#ifndef DEF_HEADER_AVATAR
#define DEF_HEADER_AVATAR

/*
Prototype des fonctions permettant la gestion de l'avatar dans la fenêtre et permet à l'utilisateur d'éditer son avatar
*/

#include "avatar_file.h"
#include "file.h"
#include "avatar_resize.h"

/*
Constantes concernant les actions de sauvegarde
*/
#define FILE_TOOLS_NONE -1
#define FILE_TOOLS_QUIT 0
#define FILE_TOOLS_SAVE 1
#define FILE_TOOLS_LOAD 2

void Avatar_Afficher_Tools(int x, int width, int height);
/*
	Affiche à l'écran les différentes couleurs pour que l'utilisateur puisse les choisir en cliquant dessus
	ARGS:
		- int x : abscisse où positionner le boîte contenant les différentes couleurs
		- int width : lageur de la boîte globale
		- int height : hauteur de la boîte globale
*/

int Avatar_Action_Tools(Avatar *ava, int x, int width, int height, int mx, int my);
/*
	Modifie la couleur sur l'avatar en fonction du clic de la souris
	ARGS:
		- Avatar *ava : l'avatar à modifier
		- int x : abscisse de position de la boîte globale à l'écran
		- int width : lageur de la boîte globale
		- int height : hauteur de la boîte globale
		- int mx : abscisse de la souris ou du selecteur
		- int my : ordonnée de la souris ou du selecteur
	RETURN:
		- 0 si rien n'a été changé
		- 1 si la couleur a été modifiée
*/

void Avatar_Afficher_File_Tools(int x, int mx, int my, int width, int height);
/*
	Affiche les boutons de sauvegarde de l'éditeur d'avatar
	On donnera aussi les coordonnées de la souris ou du selecteur pour mettre les boutons en surbrillance
	ARGS:
		- int x : abscisse de la boîte contenant les boutons
		- int mx : abscisse de la souris ou du selecteur
		- int my : ordonnée de la souris ou du selecteur
		- int width : lageur de la boîte globale
		- int height : hauteur de la boîte globale
*/

int Avatar_Action_File_Tools(int x, int mx, int my, int width, int height);
/*
	Modifie la valeur file_tools_selection pour permettre la récupération du bouton en surbrillance
	ARGS:
		- int x : abscisse de la boîte contenant les boutons
		- int mx : abscisse de la souris ou du selecteur
		- int my : ordonnée de la souris ou du selecteur
		- int width : lageur de la boîte globale
		- int height : hauteur de la boîte globale
	RETURN:
		- 0 si rien n'a été changé
		- 1 si la couleur a été modifiée
*/

void Avatar_Gest(Avatar *ava);
/*
	Fonction principale de l'éditeur d'avatar
	Gère les actions d'édition sur l'avatar
	ARGS: 
		- Avatar *ava : avatar à modifier
*/

MLV_Image *MLV_Image_CreatePalette(int width, int height, MLV_Color topleft, MLV_Color topright, MLV_Color botright, MLV_Color botleft, MLV_Color center);
/*
	Crée une MLV_Image de dimensions width x height
	Sur laquelle on crée des dégradés en suivant 5 couleurs
	ARGS:
		- int width : largeur de la MLV_Image
		- int height : hauteur de la MLV_Image
		- MLV_Color topleft : couleur du coin en haut à gauche
		- MLV_Color topright : couleur du coin en haut à droite
		- MLV_Color botleft : couleur du coin en bas à gauche
		- MLV_Color botright : couleur du coin en bas à droite
		- MLV_Color center : couleur au centre
	RETURN:
		- Renvoie la MLV_Image fabriquée
*/

#endif
