#ifndef DEF_HEADER_AVATAR_AFFICHAGE
#define DEF_HEADER_AVATAR_AFFICHAGE

#include "avatar_edit.h"

void Cercle_Afficher(Cercle c, int add_x, int add_y, MLV_Color couleur);
/*
	Affiche à l'ecran la structure Cercle en lui ajoutant les coordonnées (add_x, add_y) avec la couleur donnée
	ARGS:
		- Cercle c : Cercle à afficher
		- int add_x : abscisse depuis laquelle le centre du cercle est relatif (0 pour que ce soit des positions absolues)
		- int add_y : ordonnée depuis laquelle le centre du cercle est relatif (0 pour que ce soit des positions absolues)
		- MLV_Color couleur : couleur du cercle à afficher
*/

void Cercle_AfficherScaled(Cercle c, int add_x, int add_y, double scale, MLV_Color couleur);
/*
	Affiche à l'ecran la structure Cercle en lui ajoutant les coordonnées (add_x, add_y) avec la couleur donnée
	On peut faire varier le rayon du cerlce avec le paramètre scale
	ARGS:
		- Cercle c : Cercle à afficher
		- int add_x : abscisse depuis laquelle le centre du cercle est relatif (0 pour que ce soit des positions absolues)
		- int add_y : ordonnée depuis laquelle le centre du cercle est relatif (0 pour que ce soit des positions absolues)
		- double scale : valeur d'agrandissement du rayon du cercle (1 pour ne pas le changer)
		- MLV_Color couleur : couleur du cercle à afficher
*/

void Visage_Afficher(Visage *vis, int add_x, int add_y, MLV_Color couleur);
/*
	Affiche à l'ecran la structure Visage en lui ajoutant les coordonnées (add_x, add_y) avec la couleur donnée
	ARGS:
		- Visage *vis : Visage à afficher
		- int add_x : abscisse depuis laquelle le centre du cercle est relatif (0 pour que ce soit des positions absolues)
		- int add_y : ordonnée depuis laquelle le centre du cercle est relatif (0 pour que ce soit des positions absolues)
		- MLV_Color couleur : couleur de peau du visage à afficher
*/

void Yeux_Afficher(Yeux *yeux, int add_x, int add_y, MLV_Color couleur);
/*
	Affiche à l'ecran la structure Yeux en lui ajoutant les coordonnées (add_x, add_y)
	Ici on dessine un oeil, donc la sclérotique (fond d'oeil) sera blanche, la couleur sera celle de l'iris
	ARGS:
		- Yeux *yeux : Oeil à afficher
		- int add_x : abscisse depuis laquelle le centre du cercle est relatif (0 pour que ce soit des positions absolues)
		- int add_y : ordonnée depuis laquelle le centre du cercle est relatif (0 pour que ce soit des positions absolues)
		- MLV_Color couleur : couleur de l'iris de l'oeil
*/

void Yeux_Sourcils_Afficher(Yeux *sour, int add_x, int add_y, MLV_Color couleur);
/*
	Affiche à l'ecran la structure Yeux en lui ajoutant les coordonnées (add_x, add_y)
	Ici on dessine un sourcil, donc les coins ne sont pas symbolisés par des Cercles
	ARGS:
		- Yeux *sour : Sourcil à afficher
		- int add_x : abscisse depuis laquelle le centre du cercle est relatif (0 pour que ce soit des positions absolues)
		- int add_y : ordonnée depuis laquelle le centre du cercle est relatif (0 pour que ce soit des positions absolues)
		- MLV_Color couleur : couleur du sourcil
*/

void Yeux_Oreilles_Afficher(Yeux *sour, int add_x, int add_y, MLV_Color couleur);
/*
	Affiche à l'ecran la structure Yeux en lui ajoutant les coordonnées (add_x, add_y)
	Ici on dessine une oreille, donc de couleur unie
	ARGS:
		- Yeux *sour : Oreille à afficher
		- int add_x : abscisse depuis laquelle le centre du cercle est relatif (0 pour que ce soit des positions absolues)
		- int add_y : ordonnée depuis laquelle le centre du cercle est relatif (0 pour que ce soit des positions absolues)
		- MLV_Color couleur : couleur de peau de l'oreille
*/

void Yeux_Nez_Afficher(Yeux *nez, int add_x, int add_y, MLV_Color couleur);
/*
	Affiche à l'ecran la structure Yeux en lui ajoutant les coordonnées (add_x, add_y)
	Ici on dessine un nez, ce qui ajoute des narines
	ARGS:
		- Yeux *nez : Nez à afficher
		- int add_x : abscisse depuis laquelle le centre du cercle est relatif (0 pour que ce soit des positions absolues)
		- int add_y : ordonnée depuis laquelle le centre du cercle est relatif (0 pour que ce soit des positions absolues)
		- MLV_Color couleur : couleur de peau du nez
*/

void Cheveux_Afficher(Cheveux *chev, int add_x, int add_y, MLV_Color couleur);
/*
	Affiche à l'ecran la structure Cheveux en lui ajoutant les coordonnées (add_x, add_y)
	On dessine en fait un polygone à l'écran
	ARGS:
		- Cheveux *chev : Cheveux à afficher
		- int add_x : abscisse depuis laquelle le centre du cercle est relatif (0 pour que ce soit des positions absolues)
		- int add_y : ordonnée depuis laquelle le centre du cercle est relatif (0 pour que ce soit des positions absolues)
		- MLV_Color couleur : couleur du polygone
*/

void Cheveux_AfficherJoin(Cheveux *chev1, Cheveux *chev2, int join_rad, int add_x, int add_y, MLV_Color couleur);
/*
	Permet d'afficher la jointure entre des points de deux structures Cheveux si certains points sont à une distance plus faible que join_rad du centre de symétrie
	ARGS:
		- Cheveux *chev1 : Cheveux de référence
		- Cheveux *chev2 : Cheveux symétrique à chev1
		- int join_rad : distance en dessous de laquelle on joint les polygones
		- int add_x : abscisse depuis laquelle le centre du cercle est relatif (0 pour que ce soit des positions absolues)
		- int add_y : ordonnée depuis laquelle le centre du cercle est relatif (0 pour que ce soit des positions absolues)
		- MLV_Color couleur : couleur de la jointure
*/

void Corps_Afficher(Corps *corps, int add_x, int add_y);
/*
	Permet d'afficher la structure Corps pour l'édition
	Contrairement aux autres structures les couleurs sont des attributs des structures Corps
	ARGS:
		- Corps *corps: Corps à afficher
		- int add_x : abscisse depuis laquelle le centre du cercle est relatif (0 pour que ce soit des positions absolues)
		- int add_y : ordonnée depuis laquelle le centre du cercle est relatif (0 pour que ce soit des positions absolues)
*/

void Corps_AfficherRotate(Corps *corps, int add_x, int add_y, int add_rotate);
/*
	Permet d'afficher la structure Corps en prennant en compte les variations dues à la variable rorate de chacun
	On mettra add_rotate à 0 au début ou à l'orientation choisie
	ARGS:
		- Corps *corps: Corps à afficher
		- int add_x : abscisse depuis laquelle le centre du cercle est relatif (0 pour que ce soit des positions absolues)
		- int add_y : ordonnée depuis laquelle le centre du cercle est relatif (0 pour que ce soit des positions absolues)
		- int add_rotate : somme des rotations des membres parents ou rotation de départ
*/

void Avatar_Afficher(Avatar *ava);
/*
	Affiche l'avatar pour l'édition
	Sa position à l'écran est celle donnée par ses attributs x et y
	ARG:
		- Avatar *ava : avatar à afficher
*/

void Avatar_AfficherPerso(Avatar *ava);
/*
	Affiche l'avatar pour l'utilisation
	La différence avec l'affichage pour l'édition est que le visage est affiché à partir d'une image générée pour éviter de réafficher tous les éléments
	ARG:
		- Avatar *ava : avatar à afficher
*/

MLV_Image *Avatar_Tete(Avatar *ava);
/*
	Permet de récupérer la tete de l'avatar sous forme d'une MLV_Image
	ARG:
		- Avatar *ava : avatar dont on veut le visage
	RETURN:
		- La MLV_Image calculée de la tête de l'avatar
*/

void Avatar_Afficher_Tete_BySize(Avatar *ava, int x, int y, int size);
/*
	Affiche la tete de l'avatar selon une taille de visage donnée par size
	ARGS:
		- Avatar *ava : avatar dont on veut le visage
		- int x : abscisse où positionner la tête
		- int y : ordonnée où positionner la tête
		- int size : taille du visage à afficher
*/

MLV_Color MLV_Color_teinte(MLV_Color couleur, int teinte);
/*
	Fonction permettant l'assombrissement d'une couleur
	ARGS:
		- MLV_Color couleur : couleur de référence
		- int teinte : valeur d'intensité de la couleur
			- 0 équivaut à MLV_COLOR_BLACK
			- 255 équivaut à la couleur de référence
	RETURN:
		- la MLV_Color après application de la teinte
*/

#endif
