#ifndef DEF_HEADER_AVATAR_CALCUL
#define DEF_HEADER_AVATAR_CALCUL

#include "avatar_struct.h"

int Cercle_GetTangentes(Cercle ca, Cercle cb, Point *pa1, Point *pa2, Point *pb1, Point *pb2);
/*
	       pa1
	    ****---
	  **    ** -------   pb1
	 *        *       --**
	*     ca   *       *cb*
	*          *       *  *
	 *        *       --**
	  **    ** -------   pb2
	    ****---
	       pa2

	Permet d'obtenir les points des cercles ca et cb qui serviront à créer les tangentes (pa1, pb1) et (pa2, pb2)
	Si on prend ca à gauche et cb à droite (comme ci-dessus), (pa1, pb1) est la tangente supérieure et (pa2, pb2) la tangente inférieure
	***Cas rayon = 0
	Traiter le cas d'un cercle de rayon 0 reviendra à le considérer comme un point
	et donc donnera les tangentes de l'autre cercle passant par ce point
	ARGS:
		- Cercle ca : Premier cercle
		- Cercle cb : Deuxième cercle
		- Point *pa1 : Point de ca permettant de tracer la tangente 1, NULL s'il ne vous intéresse pas
		- Point *pa2 : Point de ca permettant de tracer la tangente 2, NULL s'il ne vous intéresse pas
		- Point *pb1 : Point de cb permettant de tracer la tangente 1, NULL s'il ne vous intéresse pas
		- Point *pb2 : Point de cb permettant de tracer la tangente 2, NULL s'il ne vous intéresse pas
	RETURN;
		- 1 si le calcul a été possible
		- 0 si le calcul n'a pas été possible: un cercle est contenu dans l'autre et n'ont pas d'intersection
*/

int Cercle_GetX_ByAngle(Cercle c, double angle, double radius_scale);
/*
	Donne la cordonnée X sur une cercle de centre du cercle et de rayon multiplié par radius_scale définie par un certain angle
	ARGS:
		- Cercle c : Cercle de référence dont on prend le centre et le rayon
		- double angle : angle dont on prendra le cosinus pour obtenir la position sur le cercle
		- double radius_scale : valeur d'agrandissement du rayon du cercle
	RETURN:
		- Abscisse obtenue
*/

int Cercle_GetY_ByAngle(Cercle c, double angle, double radius_scale);
/*
	Donne la cordonnée Y sur une cercle de centre du cercle et de rayon multiplié par radius_scale définie par un certain angle
	ARGS:
		- Cercle c : Cercle de référence dont on prend le centre et le rayon
		- double angle : angle dont on prendra le sinus pour obtenir la position sur le cercle
		- double radius_scale : valeur d'agrandissement du rayon du cercle
	RETURN:
		- Ordonnée obtenue
*/

Cercle Cercle_ByAngle(Cercle c, int degre);
/*
	Donne un ercle issu de la rotation de degre° du centre du cercle par rapport à (0, 0)
	ARGS:
		- Cercle c : cercle de référence
		- int degre : angle de rotation du centre
	RETURN:
		- Cercle obtenu après rotation du centre du cercle de référence
*/

double radian_convert(int degre);
/*
	Converti des degrés en radians
	ARGS:
		- int degre : valeur de l'angle en dégrés
	RETURN:
		- valeur de l'angle en radius
*/


#endif
