#ifndef DEF_HEADER_AVATAR_EDIT
#define DEF_HEADER_AVATAR_EDIT

#include "avatar_calcul.h"

/*
* Correspond au type choisi
Les fonctions *_MoveTo déplacent vers une position (x, y)
Les fonctions *_Move déplacent un élément par un vecteur(add_x, add_y) sous certaines conditions
Les fonctions *_Scale permettent l'agrandissement d'un cercle par une valeur add_scale
Les actions de ces fonctions s'appliquent à leur symétrique

Les fonctions *_GetNearest renvoie l'élément le plus proche d'une point pour une structure donnée
*/

int Visage_Move(Visage *vis, Visage *main_vis, int add_x, int add_y, int size);
/*
	Déplace un Visage vis par un vecteur (add_x, add_y) et déplace symétriquement son symétrique dans main_vis
	ARGS:
		- Visage *vis : Visage à déplacer
		- Visage *main_vis : Visage principal duquel est extrait vis
		- int add_x : abscisse du vecteur de déplacement
		- int add_y : ordonnée du vecteur de déplacement
		- int size : taille de référence du visage pour la gestion des contraintes
	RETURN:
		- 0 si aucune modification n'est appliquée: vecteur nul ou limité par les contraintes
		- 1 si le visage a été déplacé
*/

int Visage_MoveTo(Visage *vis, Visage *main_vis, int x, int y, int size);
/*
	Déplace un Visage vis aux cordonnées (x, y) et déplace symétriquement son symétrique dans main_vis
	ARGS:
		- Visage *vis : Visage à déplacer
		- Visage *main_vis : Visage principal duquel est extrait vis
		- int x : abscisse à laquelle on veut mettre vis
		- int y : ordonnée à laquelle on veut mettre vis
		- int size : taille de référence du visage pour la gestion des contraintes
	RETURN:
		- 0 si aucune modification n'est appliquée: vecteur nul ou limité par les contraintes
		- 1 si le visage a été déplacé
*/

int Visage_Scale(Visage *vis, Visage *main_vis, int add_scale, int size);
/*
	Agrandit un Visage vis en ajoutant add_scale au rayon du cercle associé et applique la même opération à son symétrique dans main_vis
	ARGS:
		- Visage *vis : Visage à déplacer
		- Visage *main_vis : Visage principal duquel est extrait vis
		- int add_scale : valeur à ajouter au rayon du cercle associé à vis
	RETURN:
		- 0 si aucune modification n'est appliquée: vecteur nul ou limité par les contraintes
		- 1 si le visage a été déplacé
*/

int Avatar_Yeux_Move(Avatar *ava, int add_x, int add_y);
/*
	Déplace la structure Yeux selectionnée dans l'avatar par un vecteur (add_x, add_y) et déplace symétriquement son symétrique dans l'avatar
	En considérant qu'il correspond à un oeil
	ARGS:
		- Avatar *ava : Avatar dans lequel l'oeil est selectionné
		- int add_x : abscisse du vecteur de déplacement
		- int add_y : ordonnée du vecteur de déplacement
	RETURN:
		- 0 si aucune modification n'est appliquée: vecteur nul ou limité par les contraintes
		- 1 si l'oeil a été déplacé
*/

int Avatar_Yeux_MoveTo(Avatar *ava, int x, int y);
/*
	Déplace la structure Yeux selectionnée dans l'avatar aux cordonnées (x, y) et déplace symétriquement son symétrique dans l'avatar
	En considérant qu'il correspond à un oeil
	ARGS:
		- Avatar *ava : Avatar dans lequel l'oeil est selectionné
		- int x : abscisse à laquelle on veut mettre vis
		- int y : ordonnée à laquelle on veut mettre vis
	RETURN:
		- 0 si aucune modification n'est appliquée: vecteur nul ou limité par les contraintes
		- 1 si l'oeil a été déplacé
*/

int Avatar_Yeux_Scale(Avatar *ava, int add_scale);
/*
	Agrandit le rayon du cercle de la structure Yeux selectionnée dans l'avatar par ajout de add_scale et applique la modification à son symétrique dans l'avatar
	En considérant qu'il correspond à un oeil
	ARGS:
		- Avatar *ava : Avatar dans lequel l'oeil est selectionné
		- int add_scale : valeur à ajouter au rayon du cercle associé à la selection
	RETURN:
		- 0 si aucune modification n'est appliquée: vecteur nul ou limité par les contraintes
		- 1 si l'oeil a été déplacé
*/

int Avatar_Sourcil_Move(Avatar *ava, int add_x, int add_y);
/*
	Déplace la structure Yeux selectionnée dans l'avatar par un vecteur (add_x, add_y) et déplace symétriquement son symétrique dans l'avatar
	En considérant qu'il correspond à un sourcil
	ARGS:
		- Avatar *ava : Avatar dans lequel le sourcil est selectionné
		- int add_x : abscisse du vecteur de déplacement
		- int add_y : ordonnée du vecteur de déplacement
	RETURN:
		- 0 si aucune modification n'est appliquée: vecteur nul ou limité par les contraintes
		- 1 si le sourcil a été déplacé
*/

int Avatar_Sourcil_MoveTo(Avatar *ava, int x, int y);
/*
	Déplace la structure Yeux selectionnée dans l'avatar aux cordonnées (x, y) et déplace symétriquement son symétrique dans l'avatar
	En considérant qu'il correspond à un sourcil
	ARGS:
		- Avatar *ava : Avatar dans lequel le sourcil est selectionné
		- int x : abscisse à laquelle on veut mettre vis
		- int y : ordonnée à laquelle on veut mettre vis
	RETURN:
		- 0 si aucune modification n'est appliquée: vecteur nul ou limité par les contraintes
		- 1 si le sourcil a été déplacé
*/

int Avatar_Sourcil_Scale(Avatar *ava, int add_scale);
/*
	Agrandit le rayon du cercle de la structure Yeux selectionnée dans l'avatar par ajout de add_scale et applique la modification à son symétrique dans l'avatar
	En considérant qu'il correspond à un sourcil
	ARGS:
		- Avatar *ava : Avatar dans lequel le sourcil est selectionné
		- int add_scale : valeur à ajouter au rayon du cercle associé à la selection
	RETURN:
		- 0 si aucune modification n'est appliquée: vecteur nul ou limité par les contraintes
		- 1 si le sourcil a été déplacé
*/

int Avatar_Nez_Move(Avatar *ava, int add_x, int add_y);
/*
	Déplace la structure Yeux selectionnée dans l'avatar par un vecteur (add_x, add_y)
	En considérant qu'il correspond à un nez
	ARGS:
		- Avatar *ava : Avatar dans lequel le nez est selectionné
		- int add_x : abscisse du vecteur de déplacement
		- int add_y : ordonnée du vecteur de déplacement
	RETURN:
		- 0 si aucune modification n'est appliquée: vecteur nul ou limité par les contraintes
		- 1 si le nez a été déplacé
*/

int Avatar_Nez_MoveTo(Avatar *ava, int x, int y);
/*
	Déplace la structure Yeux selectionnée dans l'avatar par un vecteur (add_x, add_y)
	En considérant qu'il correspond à un nez
	ARGS:
		- Avatar *ava : Avatar dans lequel le nez est selectionné
		- int add_x : abscisse du vecteur de déplacement
		- int add_y : ordonnée du vecteur de déplacement
	RETURN:
		- 0 si aucune modification n'est appliquée: vecteur nul ou limité par les contraintes
		- 1 si le nez a été déplacé
*/

int Avatar_Nez_Scale(Avatar *ava, int add_scale);
/*
	Agrandit le rayon du cercle de la structure Yeux selectionnée dans l'avatar par ajout de add_scale
	En considérant qu'il correspond à un nez
	ARGS:
		- Avatar *ava : Avatar dans lequel le nez est selectionné
		- int add_scale : valeur à ajouter au rayon du cercle associé à la selection
	RETURN:
		- 0 si aucune modification n'est appliquée: vecteur nul ou limité par les contraintes
		- 1 si le nez a été déplacé
*/

int Avatar_Bouche_Move(Avatar *ava, int add_y);
/*
	Déplace la structure Cercle selectionnée dans l'avatar par un vecteur (add_x, add_y)
	En considérant qu'il correspond à une bouche
	ARGS:
		- Avatar *ava : Avatar dans lequel la bouche est selectionnée
		- int add_x : abscisse du vecteur de déplacement
		- int add_y : ordonnée du vecteur de déplacement
	RETURN:
		- 0 si aucune modification n'est appliquée: vecteur nul ou limité par les contraintes
		- 1 si la bouche a été déplacée
*/

int Avatar_Bouche_MoveTo(Avatar *ava, int x, int y);
/*
	Déplace la structure Cercle selectionnée dans l'avatar par un vecteur (add_x, add_y)
	En considérant qu'il correspond à une bouche
	ARGS:
		- Avatar *ava : Avatar dans lequel la bouche est selectionnée
		- int add_x : abscisse du vecteur de déplacement
		- int add_y : ordonnée du vecteur de déplacement
	RETURN:
		- 0 si aucune modification n'est appliquée: vecteur nul ou limité par les contraintes
		- 1 si la bouche a été déplacée
*/

int Avatar_Bouche_Scale(Avatar *ava, int add_scale);
/*
	Agrandit le rayon de la structure Cercle selectionnée dans l'avatar par ajout de add_scale
	En considérant qu'il correspond à une bouche
	ARGS:
		- Avatar *ava : Avatar dans lequel la bouche est selectionnée
		- int add_scale : valeur à ajouter au rayon du cercle selectionné
	RETURN:
		- 0 si aucune modification n'est appliquée: vecteur nul ou limité par les contraintes
		- 1 si la bouche a été déplacée
*/

int Avatar_Oreille_Move(Avatar *ava, int add_x, int add_y);
/*
	Déplace la structure Yeux selectionnée dans l'avatar par un vecteur (add_x, add_y) et déplace symétriquement son symétrique dans l'avatar
	En considérant qu'il correspond à une oreille
	ARGS:
		- Avatar *ava : Avatar dans lequel l'oreille est selectionnée
		- int add_x : abscisse du vecteur de déplacement
		- int add_y : ordonnée du vecteur de déplacement
	RETURN:
		- 0 si aucune modification n'est appliquée: vecteur nul ou limité par les contraintes
		- 1 si l'oreille a été déplacée
*/

int Avatar_Oreille_MoveTo(Avatar *ava, int x, int y);
/*
	Déplace la structure Yeux selectionnée dans l'avatar aux cordonnées (x, y) et déplace symétriquement son symétrique dans l'avatar
	En considérant qu'il correspond à une oreille
	ARGS:
		- Avatar *ava : Avatar dans lequel l'oreille est selectionnée
		- int x : abscisse à laquelle on veut mettre vis
		- int y : ordonnée à laquelle on veut mettre vis
	RETURN:
		- 0 si aucune modification n'est appliquée: vecteur nul ou limité par les contraintes
		- 1 si l'oreille a été déplacée
*/

int Avatar_Oreille_Scale(Avatar *ava, int add_scale);
/*
	Agrandit le rayon du cercle de la structure Yeux selectionnée dans l'avatar par ajout de add_scale et applique la modification à son symétrique dans l'avatar
	En considérant qu'il correspond à une oreille
	ARGS:
		- Avatar *ava : Avatar dans lequel l'oreille est selectionnée
		- int add_scale : valeur à ajouter au rayon du cercle associé à la selection
	RETURN:
		- 0 si aucune modification n'est appliquée: vecteur nul ou limité par les contraintes
		- 1 si l'oreille a été déplacée
*/

int Corps_GetXY(Corps *corps, Corps *main_corps, int *x, int *y);
/*
	Permet d'obtenir les coordonnées d'un main_corps dans un corps
	ARGS:
		- Corps *corps : Corps de référence dans lequel on recherche le main_corps
		- Corps *main_corps : Corps dont on veut les coordonnées
		- int *x : abscisse du corps recherché
		- int *y : ordonnée du corps recherché
	RETURN:
		- 0 si le corps n'a pas été trouvé dans ce corps de référence
		- 1 si on a réussi à obtenir ses coordonnées
*/

int Avatar_Corps_Move(Avatar *ava, int add_x, int add_y);
/*
	Déplace la structure Corps selectionnée dans l'avatar par un vecteur (add_x, add_y) et déplace symétriquement son symétrique dans l'avatar
	ARGS:
		- Avatar *ava : Avatar dans lequel le corps est selectionné
		- int add_x : abscisse du vecteur de déplacement
		- int add_y : ordonnée du vecteur de déplacement
	RETURN:
		- 0 si aucune modification n'est appliquée: vecteur nul ou limité par les contraintes
		- 1 si le corps a été déplacé
*/

int Avatar_Corps_MoveTo(Avatar *ava, int x, int y);
/*
	Déplace la structure Corps selectionnée dans l'avatar aux cordonnées (x, y) et déplace symétriquement son symétrique dans l'avatar
	ARGS:
		- Avatar *ava : Avatar dans lequel le corps est selectionné
		- int x : abscisse à laquelle on veut mettre vis
		- int y : ordonnée à laquelle on veut mettre vis
	RETURN:
		- 0 si aucune modification n'est appliquée: vecteur nul ou limité par les contraintes
		- 1 si le corps a été déplacé
*/

int Avatar_Corps_Scale(Avatar *ava, int add_scale);
/*
	Agrandit le rayon du cercle de la structure Corps selectionnée dans l'avatar par ajout de add_scale et applique la modification à son symétrique dans l'avatar
	ARGS:
		- Avatar *ava : Avatar dans lequel le corps est selectionné
		- int add_scale : valeur à ajouter au rayon du cercle associé à la selection
	RETURN:
		- 0 si aucune modification n'est appliquée: vecteur nul ou limité par les contraintes
		- 1 si le corps a été déplacé
*/

int Avatar_Cheveux_MoveTo(Avatar *ava, int x, int y);
/*
	Déplace la structure Cheveux selectionnée dans l'avatar par un vecteur (add_x, add_y) et déplace symétriquement son symétrique dans l'avatar
	ARGS:
		- Avatar *ava : Avatar dans lequel des cheveux sont selectionnés
		- int add_x : abscisse du vecteur de déplacement
		- int add_y : ordonnée du vecteur de déplacement
	RETURN:
		- 0 si aucune modification n'est appliquée: vecteur nul ou limité par les contraintes
		- 1 si des cheveux ont été déplacés
*/

int Avatar_Cheveux_Move(Avatar *ava, int add_x, int add_y);
/*
	Déplace la structure Cheveux selectionnée dans l'avatar aux cordonnées (x, y) et déplace symétriquement son symétrique dans l'avatar
	ARGS:
		- Avatar *ava : Avatar dans lequel des cheveux sont selectionnés
		- int x : abscisse à laquelle on veut mettre vis
		- int y : ordonnée à laquelle on veut mettre vis
	RETURN:
		- 0 si aucune modification n'est appliquée: vecteur nul ou limité par les contraintes
		- 1 si des cheveux ont été déplacés
*/

Visage *Visage_GetNearest(Visage *vis, int x, int y, int *dmin);
/*
	Donne la structure Visage la plus proche des coordonnées (x, y) si elle semble selectionnable par (x, y)
	ARGS:
		- Visage *vis : Visage de référence dans laquelle on effecture la recherche
		- int x : Abscisse dont on veut le plus proche selectionnable
		- int y : Ordonnée dont on veut le plus proche selectionnable
		- int *dmin : Distance associée à la structure la plus proche, NULL si on ne veut la récupérer
	RETURN:
		- Visage selectionnable le plus proche
*/

Yeux *Yeux_GetNearest(Yeux *yeux, int x, int y, int *dmin);
/*
	Donne la structure Yeux la plus proche des coordonnées (x, y) si elle semble selectionnable par (x, y)
	ARGS:
		- Yeux *yeux : Yeux de référence dans laquelle on effecture la recherche
		- int x : Abscisse dont on veut le plus proche selectionnable
		- int y : Ordonnée dont on veut le plus proche selectionnable
		- int *dmin : Distance associée à la structure la plus proche, NULL si on ne veut la récupérer
	RETURN:
		- Yeux selectionnable le plus proche
*/

Cheveux *Cheveux_GetNearest(Cheveux *chev, int x, int y, int *dmin);
/*
	Donne la structure Cheveux la plus proche des coordonnées (x, y) si elle semble selectionnable par (x, y)
	ARGS:
		- Cheveux *chev : Cheveux de référence dans laquelle on effecture la recherche
		- int x : Abscisse dont on veut le plus proche selectionnable
		- int y : Ordonnée dont on veut le plus proche selectionnable
		- int *dmin : Distance associée à la structure la plus proche, NULL si on ne veut la récupérer
	RETURN:
		- Cheveux selectionnable le plus proche
*/

Cheveux *Cheveux_GetOposite(Cheveux *source, Cheveux *oposite, Cheveux *indice);
/*
	On considère que source et oposite sont symétriques
	indice est un élément de source
	On donne l'élément de même position qu'indice dans source pour oposite
	ARGS:
		- Cheveux *source : Liste chaînée contenant indice
		- Cheveux *oposite : Liste chaînée symétrique à source
		- Cheveux *indice : élement dont on veut l'opposé
	RETURN:
		- Cheveux opposé à indice
*/

Corps *Corps_GetNearest(Corps *corps, int x, int y, int *dmin);
/*
	Donne la structure Corps la plus proche des coordonnées (x, y) si elle semble selectionnable par (x, y)
	ARGS:
		- Corps *corps : Corps de référence dans laquelle on effecture la recherche
		- int x : Abscisse dont on veut le plus proche selectionnable
		- int y : Ordonnée dont on veut le plus proche selectionnable
		- int *dmin : Distance associée à la structure la plus proche, NULL si on ne veut la récupérer
	RETURN:
		- Corps selectionnable le plus proche
*/

int Bouche_Dist(Cercle c, int x, int y);
/*
	Donne la distance de (x, y) si elle semble selectionnable par (x, y)
	ARGS:
		- Cercle c : cercle de référence
		- int x : Abscisse dont on veut la distance au cercle
		- int y : Ordonnée dont on veut la distance au cercle
	RETURN:
		- distance entre (x, y) et le cercle s'il est selectionnable
		- -1 si le cercle n'est pas selectionnable
*/

int Avatar_MakeSelection(Avatar *ava, int x, int y);
/*
	Permet de selection un élément parmi les composants de l'avatar
	ARGS:
		- Avatar *ava : avatar dans lequel on veut effectuer une selection
		- int x : Abscisse de selection
		- int y : Ordonnée de selection
	RETURN:
		- 0 si rien n'a été selectionné
		- 1 si une selection a été effectuée
*/

int Avatar_Move(Avatar *ava, int x, int y);
/*
	Déplace l'élément selectionné de l'avatar
	ARGS:
		- Avatar *ava : avatar dans lequel on veut déplacer un composant selectionné
		- int x : Abscisse à laquelle on veut placer ce nouveau composant
		- int y : Ordonnée à laquelle on veut placer ce nouveau composant
	RETURN:
		- 0 si le composant n'a pas été déplacé
		- 1 si le composant a été déplacé
*/

int Avatar_Scale(Avatar *ava, int add_scale);
/*
	Agrandit l'élément selectionné de l'avatar en lui ajoutant add_scale
	Si l'élément est une structure Cheveux:
	- On ajout un point si add_scale > 0
	- On supprime un point si add_scale < 0
	ARGS:
		- Avatar *ava : avatar dans lequel on veut agrandir un composant selectionné
		- int add_scale : ajout de rayon à l'élément selectionné
	RETURN:
		- 0 si le composant n'a pas été modifié
		- 1 si le composant a été modifié
*/

void Avatar_FullMoveTo(Avatar *ava, int x, int y);
/*
	Déplace l'avatar dans son ensemble aux coordonées (x, y)
	ARGS:
		- Avatar *ava : avatar dans lequel on veut déplacer un composant selectionné
		- int x : Abscisse à laquelle on veut placer l'avatar
		- int y : Ordonnée à laquelle on veut placer l'avatar	
*/

#endif
