#include "avatar_file.h"

static int amuser_Wall = 1;

void Point_Save(Point p, FILE *flux)
{
	fprintf(flux, "%d %d\n", p.x, p.y);
}

void Cercle_Save(Cercle c, FILE *flux)
{
	fprintf(flux, "%d ", c.rayon);
	Point_Save(c.centre, flux);
}

void Visage_Save(Visage *vis, FILE *flux)
{
	int i;
	for(i = 0; i < VISAGE_NB_CERCLES; i ++)
	{
		Cercle_Save(vis->cercle, flux);
		vis = vis->next;
	}
	fprintf(flux, "\n");
}

void Yeux_Save(Yeux *yeux, FILE *flux)
{
	while(yeux != NULL)
	{
		Cercle_Save(yeux->cercle, flux);
		yeux = yeux->next;
	}
	fprintf(flux, "\n");
}

void Cheveux_Save(Cheveux *chev, FILE *flux)
{
	while(chev != NULL)
	{
		fprintf(flux, "coord: ");
		Point_Save(chev->centre, flux);
		chev = chev->next;
	}
	fprintf(flux, "end\n\n");
}

void MLV_Color_Save(MLV_Color couleur, FILE *flux)
{
	Color scolor = MLV_Color_To_Color(couleur);
	fprintf(flux, "%d %d %d %d\n", scolor.r, scolor.g, scolor.b, scolor.a);
}

void Corps_Save(Corps *corps, FILE *flux)
{
	if(corps != NULL)
	{
		Cercle_Save(corps->cercle, flux);
		MLV_Color_Save(corps->couleur, flux);
		fprintf(flux, "%d %d\n%d %d\n%d %d\n\n", corps->x_min, corps->x_max, corps->y_min, corps->y_max, corps->ray_min, corps->ray_max);
		int i;
		for(i = 0; i < corps->nb_child; i ++)
		{
			Corps_Save(corps->child[i], flux);
		}
	}
}

int Avatar_Save(Avatar *ava, const char *file_name)
{
	if(file_name == NULL)
		return 0;
	printf("Save avatar %s\n", file_name);
	FILE *fich = NULL;
	if((fich = fopen(file_name, "w")) == NULL)
		return 0;
	fprintf(fich, "TTG_Avatar_1.0\n");
	fprintf(fich, "%d\n", ava->visage_size);
	fprintf(fich, "%d\n\n", ava->corps_height);
	Visage_Save(ava->visage, fich);
	Yeux_Save(ava->oeil_droit, fich);
	Yeux_Save(ava->oeil_gauche, fich);
	Yeux_Save(ava->sourcil_droit, fich);
	Yeux_Save(ava->sourcil_gauche, fich);
	Yeux_Save(ava->oreille_droite, fich);
	Yeux_Save(ava->oreille_gauche, fich);
	Yeux_Save(ava->nez, fich);
	Cercle_Save(ava->bouche, fich);
	fprintf(fich, "\n");
	Cheveux_Save(ava->cheveux_droite, fich);
	Cheveux_Save(ava->cheveux_gauche, fich);
	MLV_Color_Save(ava->couleur_peau, fich);
	MLV_Color_Save(ava->couleur_poils, fich);
	MLV_Color_Save(ava->couleur_yeux, fich);
	fprintf(fich, "\n");
	Corps_Save(ava->corps, fich);
	fprintf(fich, "%d\n", ava->corps->cercle.centre.y-ava->y);
	fclose(fich);
	return 1;
}

Point Point_Load(FILE *flux)
{
	Point p;
	amuser_Wall =fscanf(flux, "%d %d", &(p.x), &(p.y));
	return p;
}

Cercle Cercle_Load(FILE *flux)
{
	Cercle c;
	amuser_Wall =fscanf(flux, "%d", &(c.rayon));
	c.centre = Point_Load(flux);
	return c;
}

void Visage_Load(Visage *vis, FILE *flux)
{
	int i;
	for(i = 0; i < VISAGE_NB_CERCLES; i ++)
	{
		vis->cercle = Cercle_Load(flux);
		vis = vis->next;
	}
}

void Yeux_Load(Yeux *yeux, FILE *flux)
{
	while(yeux != NULL)
	{
		yeux->cercle = Cercle_Load(flux);
		yeux = yeux->next;
	}
}

void Cheveux_Load(Cheveux **chev, FILE *flux)
{
	Cheveux_Free(chev);
	char get_texte[25];
	do
	{
		amuser_Wall =fscanf(flux, "%s", get_texte);
		if(strcmp(get_texte, "end"))
		{
			Cheveux_AjoutBefore(chev, *chev, Point_Load(flux));
		}
	}while(strcmp(get_texte, "end"));
}

MLV_Color MLV_Color_Load(FILE *flux)
{
	Color scolor;
	amuser_Wall =fscanf(flux, "%d %d %d %d\n", &(scolor.r), &(scolor.g), &(scolor.b), &(scolor.a));
	return Color_To_MLV_Color(scolor);
}

void Corps_Load(Corps *corps, FILE *flux)
{
	if(corps != NULL)
	{
		corps->cercle = Cercle_Load(flux);
		corps->couleur = MLV_Color_Load(flux);
		amuser_Wall =fscanf(flux, "%d %d %d %d %d %d", &(corps->x_min), &(corps->x_max), &(corps->y_min), &(corps->y_max), &(corps->ray_min), &(corps->ray_max));
		int i;
		for(i = 0; i < corps->nb_child; i ++)
		{
			Corps_Load(corps->child[i], flux);
		}
	}
}

int Avatar_Load(Avatar *ava, const char *file_name)
{
	if(file_name == NULL)
		return 0;
	printf("Load avatar %s\n", file_name);
	FILE *fich = NULL;
	if((fich = fopen(file_name, "r")) == NULL)
		return 0;
	char verif[100];
	amuser_Wall =fscanf(fich, "%s", verif);
	if(strcmp(verif, "TTG_Avatar_1.0"))
	{
		fclose(fich);
		return 0;
	}
	amuser_Wall =fscanf(fich, "%d", &(ava->visage_size));
	amuser_Wall =fscanf(fich, "%d", &(ava->corps_height));
	Visage_Load(ava->visage, fich);
	Yeux_Load(ava->oeil_droit, fich);
	Yeux_Load(ava->oeil_gauche, fich);
	Yeux_Load(ava->sourcil_droit, fich);
	Yeux_Load(ava->sourcil_gauche, fich);
	Yeux_Load(ava->oreille_droite, fich);
	Yeux_Load(ava->oreille_gauche, fich);
	Yeux_Load(ava->nez, fich);
	ava->bouche = Cercle_Load(fich);
	Cheveux_Load(&(ava->cheveux_droite), fich);
	Cheveux_Load(&(ava->cheveux_gauche), fich);
	ava->couleur_peau = MLV_Color_Load(fich);
	ava->couleur_poils = MLV_Color_Load(fich);
	ava->couleur_yeux = MLV_Color_Load(fich);
	Corps_Load(ava->corps, fich);
	amuser_Wall =fscanf(fich, "%d", &(ava->corps->cercle.centre.y));
	ava->corps->cercle.centre.y = ava->corps->cercle.centre.y+ava->y;
	ava->corps->cercle.centre.x = ava->x;
	fclose(fich);
	Corps_SetColor(CORPS_MAIN_D(ava->corps), ava->couleur_peau);
	Corps_SetColor(CORPS_MAIN_G(ava->corps), ava->couleur_peau);
	Corps_SetColor(CORPS_COU(ava->corps), ava->couleur_peau);
	if(ava->tete != NULL)
		MLV_free_image(ava->tete);
	ava->tete = Avatar_Tete(ava);
	ava->modified = 0;
	return 1;
}
