#ifndef DEF_HEADER_AVATAR_STRUCT
#define DEF_HEADER_AVATAR_STRUCT

#include <MLV/MLV_all.h>
#include <math.h>
#include <stdarg.h>
#include "annexe.h"

/*
Macros permettant une utilisation plus simple et compréhensible d'un visage
*/
#define VISAGE_CRANE(vis) (vis)
#define VISAGE_MACHOIRE_GAUCHE(vis) (vis->prev)
#define VISAGE_MACHOIRE_DROITE(vis) (vis->next)
#define VISAGE_MENTON_GAUCHE(vis) (vis->prev->prev)
#define VISAGE_MENTON_DROITE(vis) (vis->next->next)
#define VISAGE_NB_CERCLES 5

/*
Macros permettant une utilisation plus simple et compréhensible d'un oeil
*/
#define YEUX_INTERNE(yeux) (yeux)
#define YEUX_MIDDLE(yeux) (yeux->next)
#define YEUX_EXTERNE(yeux) (yeux->next->next)
#define YEUX_NB_CERCLES 3

/*
Macros permettant une utilisation plus simple et compréhensible d'un sourcil
*/
#define SOURCILS_INTERNE(sour) (sour)
#define SOURCILS_MIDINTERNE(sour) (sour->next)
#define SOURCILS_MIDEXTERNE(sour) (sour->next->next)
#define SOURCILS_EXTERNE(sour) (sour->next->next->next)
#define SOURCILS_NB_CERCLES 4

/*
Macros permettant une utilisation plus simple et compréhensible d'un nez
*/
#define NEZ_GAUCHE(nez) (nez)
#define NEZ_MIDDLE(nez) (nez->next)
#define NEZ_DROITE(nez) (nez->next->next)
#define NEZ_NB_CERCLES 3

/*
Macros permettant une utilisation plus simple et compréhensible d'une oreille
*/
#define OREILLE_HAUT(ore) (ore)
#define OREILLE_MID(ore) (ore->next)
#define OREILLE_BAS(ore) (ore->next->next)

/*
Macros permettant une utilisation plus simple et compréhensible d'un corps
*/
#define CORPS_COU(corps) (corps)
#define CORPS_BUSTE(corps) (corps->child[0])
#define CORPS_VENTRE(corps) (CORPS_BUSTE(corps)->child[0])
#define CORPS_EPAULE_D(corps) (CORPS_BUSTE(corps)->child[1])
#define CORPS_EPAULE_G(corps) (CORPS_BUSTE(corps)->child[2])
#define CORPS_BRAS_D(corps) (CORPS_EPAULE_D(corps)->child[0])
#define CORPS_BRAS_G(corps) (CORPS_EPAULE_G(corps)->child[0])
#define CORPS_AVB_D(corps) (CORPS_BRAS_D(corps)->child[0])
#define CORPS_AVB_G(corps) (CORPS_BRAS_G(corps)->child[0])
#define CORPS_MAIN_D(corps) (CORPS_AVB_D(corps)->child[0])
#define CORPS_MAIN_G(corps) (CORPS_AVB_G(corps)->child[0])
#define CORPS_BASSIN(corps) (CORPS_VENTRE(corps)->child[0])
#define CORPS_CUISSE_D(corps) (CORPS_BASSIN(corps)->child[0])
#define CORPS_CUISSE_G(corps) (CORPS_BASSIN(corps)->child[1])
#define CORPS_TIBIA_D(corps) (CORPS_CUISSE_D(corps)->child[0])
#define CORPS_TIBIA_G(corps) (CORPS_CUISSE_G(corps)->child[0])
#define CORPS_PIED_D(corps) (CORPS_TIBIA_D(corps)->child[0])
#define CORPS_PIED_G(corps) (CORPS_TIBIA_G(corps)->child[0])

/*
Enum des différentes couleurs modifiables sur l'avatar
*/
enum {AVATAR_COULEUR_PEAU, AVATAR_COULEUR_POILS, AVATAR_COULEUR_YEUX, AVATAR_COULEUR_HAUT, AVATAR_COULEUR_BAS, AVATAR_COULEUR_PIED, AVATAR_NB_COLOR};

typedef struct _Point Point;
struct _Point
{
	int x;//Abscisse
	int y;//Ordonnée
};

typedef struct _Cercle Cercle;
struct _Cercle
{
	Point centre;//Centre du cercle
	int rayon;//Rayon du cercle
};

typedef struct _Visage Visage;
/*
Liste chaînée circulaire de cercles permettant de construire le visage de notre avatar
Elle revient sur le permier élément
*/
struct _Visage
{
	Cercle cercle;//Partie d'un visage souvent déplaçable et modifiable (sauf pour le crane)
	Visage *next;//Partie du visage suivante
	Visage *prev;//Partie du visage précédente
};

typedef struct _Yeux Yeux;
/*
Liste chaînée simple de cercles permettant de construire les yeux, le nez, les oreilles et les sourcils
NULL est placé à la fin de la liste
*/
struct _Yeux
{
	Cercle cercle;//Elémément stocké par la liste chaînée
	Yeux *next;//Structure Yeux suivante dans la liste chaînée
};

typedef struct _Cheveux Cheveux;
/*
Liste chaînée simple de points permettant de construire un polygone, ici pour représenter les cheveux de l'avatar
NULL est placé à la fin de la liste
*/
struct _Cheveux
{
	Point centre;//Point du polygône
	Cheveux *next;//Point suivant
};

typedef struct _Corps Corps;
/*
Arbre de cercles permettant de construire le corps de l'avatar
*/
struct _Corps
{
	Cercle cercle;//Les coordonées du cercle sont relatives à celle de son parent et absolues si le parent est NULL
	int x_min;//Abscisse minimale du centre du cercle
	int x_max;//Abscisse maximale du centre du cercle
	int y_min;//Ordonnée minimale du centre du cercle
	int y_max;//Ordonnée maximale du centre du cercle
	int ray_min;//Rayon minimal du cercle
	int ray_max;//Rayon maximal du cercle
	int nb_child;//Nombre de Corps* suivants
	int parent_part;//Détermine si c'est une partie directement connectée à son parent dans l'affichage
	MLV_Color couleur;//Couleur du cercle
	int rotate;//Rotation de l'articulation
	Corps **child;//Tableau des membres suivants de cette structure Corps
	Corps *parent;//Parent de ce membre
};

typedef union _Avatar_Selection Avatar_Selection;
/*
Union permettant de stocker l'élément selectionné
On connaît son type grâce à une variable Avatar_Selection_Id
*/
union _Avatar_Selection
{
	Visage *visage;
	Yeux *yeux;
	Cheveux *cheveux;
	Corps *corps;
};

typedef enum _Avatar_Selection_Id Avatar_Selection_Id;
/*
Variable permettant de connaître l'appartenance de l'élément selectionné
*/
enum _Avatar_Selection_Id
{
	ASI_None,
	ASI_Visage,
	ASI_Oeil_Droit,
	ASI_Oeil_Gauche,
	ASI_Sourcil_Droit,
	ASI_Sourcil_Gauche,
	ASI_Nez,
	ASI_Bouche,
	ASI_Oreille_Droite,
	ASI_Oreille_Gauche,
	ASI_Cheveux_Droite,
	ASI_Cheveux_Gauche,
	ASI_Corps
};

typedef struct _Avatar Avatar;
/*
Structure regroupant les différentes informations liées à l'avatar
*/
struct _Avatar
{
	int x, y;//Coordonnées de l'avatar
	Visage *visage;//Visage de l'avatar
	int visage_size;//Taille du visage de l'avatar (utile pour les contraintes par exemple)
	int corps_height;//Taille du corps
	int modified;//Indique si l'avatar a été modifié pour recalculer son visage sous forme d'image (MLV_Image *tete)
	Yeux *oeil_droit;//Oeil droit
	Yeux *oeil_gauche;//Oeil gauche
	Yeux *sourcil_droit;//Sourcil droit
	Yeux *sourcil_gauche;//Sourcil gauche
	Yeux *nez;//Nez
	Yeux *oreille_droite;//Oreille droite
	Yeux *oreille_gauche;//Oreille gauche
	Cercle bouche;//Bouche
	Cheveux *cheveux_droite;//Cheveux côté droit
	Cheveux *cheveux_gauche;//Cheveux côté gauche
	Corps *corps;//Corps
	MLV_Color couleur_peau;//Couleur de peau
	MLV_Color couleur_yeux;//Couleur des yeux
	MLV_Color couleur_poils;//Couleur des poils
	Avatar_Selection selection;//Union contenant l'élément selectionné
	Avatar_Selection_Id choix_selection;//Indication permettant de connaître le type et la structure à laquelle appartient l'élément selectionné
	MLV_Image *tete;//Image de la tête de l'avatar (pour ne pas avoir à réafficher les éléments permettant l'édition si ce n'est pas necessaire)
	int tx, ty;//Coordonnées de la tete
};

typedef struct _Color Color;
/*
Structure permettant une manipulation plus simple des valeurs RGBA
*/
struct _Color
{
	int r;
	int g;
	int b;
	int a;
};

Corps *Corps_Create(Cercle c);
/*
	Permet d'allouer dynamiquement une structure Corps
	ARG:
		- Cercle c : Cercle permettant l'initialisation de la structure
	RETURN:
		- Corps alloué dynamiquement
*/

int Corps_DefChild(Corps *corps, int nb_child);
/*
	Défini le nombre de suivants d'un corps
	ARGS:
		- Corps *corps : Corps concerné
		- int nb_child : nombre de suivants
	RETURN:
		- 0 echec d'allocation
		- 1 réussite
*/

void Corps_DefPart(Corps *corps, int x, int y, int rayon, int min_x, int min_y, int max_x, int max_y, double min_ray, double max_ray);
/*
	Défini les différents éléments d'un corps
	ARGS:
		- Corps *corps : Corps à éditer
		- int x : Abscisse relative à son parent
		- int y : Ordonnée relative à son parent
		- int rayon : rayon du cercle
		- int min_x : contrainte gauche
		- int min_y : contrainte haut
		- int max_x : contrainte droite
		- int max_y : contrainte bas
		- double min_ray : rayon minimal possible
		- double max_ray : rayon maximal possible
*/

void Corps_SetColor(Corps *corps, MLV_Color couleur);
/*
	Défini la couleur d'un corps et applique l'opération aux suivants qui lui sont lié par la couleur (attribut parent_part à 1)
	ARGS:
		- Corps *corps : Corps concerné
		- MLV_Color couleur : couleur à appliquer
*/

Corps *Corps_CreateHuman(int x, int y, int size_x, int size_y);
/*
	Renvoie la base d'un corps qui représente une forme humaine
	ARGS:
		- int x : Abscisse de la base du corps
		- int y : Ordonnée de la base du corps
		- int size_x : Largeur du corps
		- int size_y : Hauteur du corps
	RETURN:
		- base du Corps créé
*/

void Corps_Free(Corps **corps);
/*
	Libère une structure Corps dans sa totalité (suivants inclus)
	ARG:
		- Corps **corps : Adresse du corps à libérer
*/

MLV_Color Color_To_MLV_Color(Color couleur);
/*
	Converti une structure Color en MLV_Color
	ARG:
		- Color couleur : structure Color que dont on veut la MLV_Color
	RETURN:
		- MLV_Color équivalente à la structure Color en argument
*/

Color MLV_Color_To_Color(MLV_Color couleur);
/*
	Converti une structure MLV_Color en Color
	ARG:
		- MLV_Color couleur : structure MLV_Color que dont on veut la structure Color
	RETURN:
		- Color équivalente à la MLV_Color en argument
*/

MLV_Color MLV_Color_Mix(int nb_color, ...);
/*
	Mélange une liste de couleurs selon l'intensité de chacune dans le mélange
	Exemple:
		MLV_Color_Mix(3, MLV_COLOR_BLACK, 1000, MLV_COLOR_BLUE, 5000, MLV_COLOR_RED, 4000)
		Donnera la MLV_Color composée de 10% MLV_COLOR_BLACK
						 50% MLV_COLOR_BLUE
						 40% MLV_COLOR_RED
		C'est la somme des intensités qui équivaut à 100%, vous fixez les intensités selon votre échelle
	ARGS:
		- int nb_color : nombre de couleurs en argument
		Pour chaque couleur:
			- MLV_Couleur couleur : couleur à mixer
			- int intensité : intensité de cette couleur dans le mélange (selon votre échelle)
	RETURN:
		- MLV_Color issue du mélange
*/

Visage *Visage_AllouePart(Cercle c);
/*
	Alloue dynamiquement une structure Visage
	ARG:
		- Cercle c : valeur d'initialisation
	RETURN:
		- Visage alloué dynamiquement
*/

Visage *Visage_Create();
/*
	Crée un Visage à 5 éléments
	RETURN:
		- Visage alloué dynamiquement
*/

void Visage_Init(Visage *vis, int size);
/*
	Initialise un visage à 5 éléments
	ARGS:
		- Visage *vis : Visage à initialiser
		- int size : Taille du visage
*/

void Visage_Free(Visage **vis);
/*
	Libère un visage ainsi que ses suivants
	ARG:
		- Visage **vis : Visage à libérer
*/

Yeux *Yeux_AllouePart(Cercle c);
/*
	Alloue dynamiquement une structure Yeux
	ARG:
		- Cercle c : valeur d'initialisation
	RETURN:
		- Yeux alloué dynamiquement
*/

Yeux *Yeux_Create(int nb);
/*
	Crée une structure Yeux d'un certain nombre d'éléments
	ARG:
		- int nb : nombre d'éléments de la liste chaînée
	RETURN:
		- structure Yeux créée
*/

void Yeux_Free(Yeux **yeux);
/*
	Libère une structure Yeux ainsi que ses suivants
	ARG:
		- Yeux **yeux : Yeux à libérer
*/

Cheveux *Cheveux_AllouePart(Point p);
/*
	Alloue dynamiquement une structure Cheveux
	ARG:
		- Point p : valeur d'initialisation
	RETURN:
		- Cheveux alloué dynamiquement
*/

int Cheveux_AjoutBefore(Cheveux **chev, Cheveux *indice, Point p);
/*
	Ajoute un point dans une structure Cheveux avant un certain indice représenté par un élément de cette structure
	ARGS:
		- Cheveux **chev : Début de la liste chaînée à modifier
		- Cheveux *indice : Structure servant d'indice
		- Point p : élément à ajouter à la liste
	RETURN:
		- 0 si l'élément n'a pas pu être ajouté
		- 1 l'élément a été ajouté
*/

int Cheveux_Remove(Cheveux **chev, Cheveux **indice);
/*
	Retire un élément d'une liste chaînée Cheveux
	ARGS:
		- Cheveux **chev : Liste de référence dans laquelle élément doit être supprimé
		- Cheveux **indice : élément à supprimer
	RETURN:
		- 0 si l'élément ou la liste est NULL
		- 1 si l'élément a été retiré
*/

Cheveux *Cheveux_Create(int nb);
/*
	Crée une structure Cheveux d'un certain nombre d'éléments
	ARG:
		- int nb : nombre d'éléments de la liste chaînée
	RETURN:
		- structure Cheveux créée
*/

void Cheveux_Free(Cheveux **chev);
/*
	Libère une structure Cheveux ainsi que ses suivants
	ARG:
		- Cheveux **chev : Cheveux à libérer
*/

Avatar *Avatar_Create();
/*
	Crée une structure avatar allouée dynamiquement
	RETURN:
		- Avatar créé
*/

void Avatar_Init(Avatar *ava, int x, int y, int visage_size, int corps_size);
/*
	Initialise un avatar
	ARGS:
		- Avatar *ava : Avatar à initialiser
		- int x : Abscisse de l'avatar
		- int y : Ordonnée de l'avatar
		- int visage_size : Taille du visage
		- int corps_size : Taille du corps
*/

void Avatar_Free(Avatar **ava);
/*
	Libère une structure Avatar allouée dynamiquement
	ARG:
		- Avatar **ava : Avatar à libérer
*/

#endif
