#include "init_data.h"

PlayedToken *PlayedToken_Create()
{
	PlayedToken *jetonjoue = (PlayedToken*)malloc(sizeof(PlayedToken));
	//jetonjoue->jeton = Token_Create();
	jetonjoue->next = NULL;
	jetonjoue->nextColor = NULL;
	jetonjoue->prevColor = NULL;
	jetonjoue->nextForm = NULL;
	jetonjoue->prevForm = NULL;
	return jetonjoue;
}

void PlayedToken_Free(PlayedToken **jetonjoue)
{
	if(*jetonjoue != NULL)
	{
		free(*jetonjoue);
		*jetonjoue = NULL;
	}
}

void PlayedToken_FreeWithNext(PlayedToken **jetonjoue)
{
	if(*jetonjoue != NULL)
	{
		PlayedToken_FreeWithNext(&((*jetonjoue)->next));//Cas jetonjoue->next==NULL géré par cette même fonction
		PlayedToken_Free(jetonjoue);
	}
}

TokenList *TokenList_Create()
{
	TokenList *listejeton = (TokenList*)malloc(sizeof(TokenList));
	listejeton->head = NULL;
	listejeton->tail = NULL;
	listejeton->taille = 0;
	int i;
	for(i = 0; i < NB_COLOR; i ++)
	{
		listejeton->head_color[i] = NULL;
	}
	for(i = 0; i < NB_SHAPE; i ++)
	{
		listejeton->head_shape[i] = NULL;
	}
	return listejeton;
}

void TokenList_Free(TokenList **listejeton)
{
	if(*listejeton != NULL)
	{
		PlayedToken_FreeWithNext(&((*listejeton)->head));
		free(*listejeton);
		*listejeton = NULL;
	}
}

AnimToken *AnimToken_Create()
{
	AnimToken *jetonanim = (AnimToken*)malloc(sizeof(AnimToken));
	//jetonanim->jeton = Token_Create();
	jetonanim->next = NULL;
	jetonanim->disparition = 0;
	jetonanim->anim_id = -1;
	return jetonanim;
}

void AnimToken_Free(AnimToken **jetonanim)
{
	if(*jetonanim != NULL)
	{
		free(*jetonanim);
		*jetonanim = NULL;
	}
}

void AnimToken_FreeWithNext(AnimToken **jetonanim)
{
	if(*jetonanim != NULL)
	{
		AnimToken_FreeWithNext(&((*jetonanim)->next));
		AnimToken_Free(jetonanim);
	}
}

AnimList *AnimList_Create()
{
	AnimList *listeanim = (AnimList*)malloc(sizeof(AnimList));
	listeanim->head = NULL;
	listeanim->tail = NULL;
	listeanim->taille = 0;
	return listeanim;
}

void AnimList_Free(AnimList **listeanim)
{
	if(listeanim != NULL)
	{
		AnimToken_FreeWithNext(&((*listeanim)->head));
		free(*listeanim);
		*listeanim = NULL;
	}
}

AnimData *AnimData_Create()
{
	AnimData *animdata = (AnimData*)malloc(sizeof(AnimData));
	animdata->listeanim = AnimList_Create();
	int i, j, k, l;
	for(i = 0; i < NB_COLOR; i ++)
	{
		for(j = 0; j < NB_SHAPE; j ++)
		{
			animdata->jetonimage[i][j] = NULL;
			for(k = 0; k < NB_ANIM_IMG; k ++)
			{
				for(l = 0; l < NB_FRAMES; l ++)
				{
					animdata->jetonimageanim[i][j][k][l] = NULL;
				}
			}
		}
	}
	animdata->loaded = 0;
	return animdata;
}

void AnimData_Free(AnimData **animdata)
{
	if(*animdata != NULL)
	{
		AnimList_Free(&((*animdata)->listeanim));
		int i, j, k, l;
		for(i = 0; i < NB_COLOR; i ++)
		{
			for(j = 0; j < NB_SHAPE; j ++)
			{
				if((*animdata)->jetonimage[i][j] != NULL)
					MLV_free_image((*animdata)->jetonimage[i][j]);
				(*animdata)->jetonimage[i][j] = NULL;
				for(k = 0; k < NB_ANIM_IMG; k ++)
				{
					for(l = 0; l < NB_FRAMES; l ++)
					{
						if((*animdata)->jetonimageanim[i][j][k][l] != NULL)
							MLV_free_image((*animdata)->jetonimageanim[i][j][k][l]);
						(*animdata)->jetonimageanim[i][j][k][l] = NULL;
					}
				}
			}
		}
		free(*animdata);
		*animdata = NULL;
	}
}

void AnimData_Clear(AnimData *animdata)
{
	if(animdata != NULL)
	{
		AnimToken_FreeWithNext(&(animdata->listeanim->head));
		animdata->listeanim->tail = NULL;
		animdata->listeanim->taille = 0;
	}
}

Tuto *Tuto_Create()
{
	Tuto *t = NULL;
	if((t = (Tuto*)malloc(sizeof(Tuto))) == NULL)
		return NULL;
	t->message = NULL;
	t->x = 0;
	t->y = 0;
	t->control_action = Control_None;
	t->cr_action = CR_None;
	t->next = NULL;
	return t;
}

void Tuto_Free(Tuto **t)
{
	if(*t != NULL)
	{
		Tuto_Free(&((*t)->next));
		if((*t)->message != NULL)
			free((*t)->message);
		free(*t);
		*t = NULL;
	}
}

int Jeu_Create()
{
	jeu = NULL;
	if((jeu = (Jeu*)malloc(sizeof(Jeu))) == NULL)
		return 0;
	jeu->win = 0;
	jeu->score = 0;
	jeu->actif = 1;
	jeu->need_refresh = 1;
	jeu->width = MLV_get_desktop_width();
	jeu->height = MLV_get_desktop_height();
	jeu->police = NULL;
	if((jeu->police = MLV_load_font("media/arial.ttf", 25)) == NULL)
		return 0;
	
	jeu->nb_colors = NB_COLOR;
	jeu->nb_shapes = NB_SHAPE;
	jeu->is_tuto = 0;
	jeu->is_loaded = 0;
	
	jeu->genjeton = NULL;
	jeu->listejeton = NULL;
	jeu->animdata = NULL;
	jeu->plateau = NULL;
	if((jeu->animdata = AnimData_Create()) == NULL)
		return 0;
	jeu->avatar = Avatar_Create();
	Avatar_Init(jeu->avatar, 133, 75, 266, 300);
	jeu->avatar->tete = Avatar_Tete(jeu->avatar);
	
	jeu->game_mode = Game_Mode_Base;
	jeu->prepare_sprites = NULL;
	jeu->afficher = NULL;
	jeu->afficher_Liste = NULL;
	jeu->afficher_AnimList = NULL;
	jeu->afficher_control = NULL;
	jeu->afficher_plateau = NULL;
	jeu->afficher_jeton = NULL;
	jeu->get_control_action = NULL;
	jeu->get_PlayedToken = NULL;
	jeu->afficher_choix_rotate = NULL;
	jeu->get_choix_rotate_action = NULL;
	jeu->afficher_rotate = NULL;
	jeu->move_jeton = NULL;
	jeu->startPosX = NULL;
	jeu->startPosY = NULL;
	jeu->afficher_ajout_score = NULL;
	return 1;
}

void Jeu_Free()
{
	TokenList_Free(&(jeu->listejeton));
	TokenList_Free(&(jeu->genjeton));
	AnimData_Free(&(jeu->animdata));
	MLV_free_font(jeu->police);
	if(jeu->plateau != NULL)
		MLV_free_image(jeu->plateau);
	jeu->police = NULL;
	free(jeu);
}
