#include "menu.h"


Button *Button_Init(int x, int y, int padding, const char text[], MLV_Font *font, void *function)
{
	Button *temp = (Button *)malloc(sizeof(Button));
	if(temp == NULL)
		return NULL;
	temp->x = x;
	temp->y = y;
	temp->value = (char *)malloc(sizeof(char)*(strlen(text)+1));
	if(temp->value == NULL)
	{
		free(temp);
		return NULL;
	}
	strcpy(temp->value, text);
	temp->font = font;
	temp->function = function;
	temp->width=0;
	temp->height=0;
	temp->hover=0;
	temp->anim=0;
	temp->borderActive=-1;
	temp->padding=padding;
	MLV_get_size_of_adapted_text_box_with_font(temp->value, temp->font, 0, &(temp->width), &(temp->height));
	temp->x -= (int)(temp->width/2.0)+padding;
	temp->y -= (int)(temp->height/2.0)+padding;
	temp->width += padding*2;
	temp->height += padding;
	
	return temp;
}
void Button_Free(Button **temp)
{
	if(*temp != NULL)
	{
		if((*temp)->value != NULL)
		{
			free((*temp)->value);
		}
		free(*temp);
	}
	*temp = NULL;
}
ButtonList *ButtonList_Init(void)
{
	ButtonList *temp = (ButtonList *)malloc(sizeof(ButtonList));
	if(temp == NULL)
		return NULL;
	temp->nb=0;
	temp->max_width=0;
	int i;
	for(i=0;i<MAX_BUTTONS;i++)
		temp->tab[i] = NULL;
	
	MLV_change_frame_rate(60);
	
	return temp;
}
void ButtonList_FreeAll(ButtonList **lst)
{
	if(*lst != NULL)
	{
		int i;
		for(i=0;i<(*lst)->nb;i++)
		{
			Button_Free(&((*lst)->tab[i]));
		}
		free(*lst);
	}
	*lst = NULL;
}
int ButtonList_AddButton(ButtonList *lst, int x, int y, int padding, const char text[], MLV_Font *font, int (*function)())
{
	if(lst == NULL)
		return 0;
	if(lst->nb >= MAX_BUTTONS)
	{
		printf("<ButtonList_AddButton> : Already too many buttons in mem (Try increase MAX_BUTTONS)\n");
		return 0;
	}
	Button *temp = Button_Init(x,y,padding,text,font,function);
	if(temp == NULL)
		return 0;
	lst->tab[lst->nb] = temp;
	lst->nb++;
	if(temp->width>lst->max_width)
		lst->max_width = temp->width;
	return 1;
}
void Button_Aff(Button *temp)
{
	if(temp != NULL)
	{
		MLV_Color colorText = MLV_rgba(50,50,50,255);
		MLV_Color colorText2 = MLV_rgba(10,10,10,255);
		if(temp->hover == 1)
		{
			colorText = MLV_rgba(180,180,180,255);
			if((temp->borderActive)%3==0)
				colorText2 = MLV_rgba(200,200,200,255);
			else if(temp->borderActive%3==1)
				colorText2 = MLV_rgba(0,0,210,255);
			else
				colorText2 = MLV_rgba(220,0,0,255);
		}
		if(temp->anim)
		{
			srand(time(NULL)+temp->borderActive);
			int baseX=rand()%4;
			int baseY=rand()%4;
			int o = rand()%2;
			if(o == 1)
				baseX *= -1;
			o =rand()%2;
			if(o == 1)
				baseY *= 1;
			if(!(temp->hover))
			{
				baseX=0;
				baseY=0;
			}
			MLV_draw_filled_rectangle(temp->x, temp->y, temp->width, temp->height, MLV_rgba(15,15,15,255));
		
			MLV_draw_text_with_font(temp->x+temp->padding+1+baseX, temp->y+temp->padding+1+baseY, temp->value, temp->font, colorText2);
			MLV_draw_text_with_font(temp->x+temp->padding-1+baseX, temp->y+temp->padding-1+baseY, temp->value, temp->font, colorText2);
			MLV_draw_text_with_font(temp->x+temp->padding+baseX, temp->y+temp->padding+baseY, temp->value, temp->font, colorText);
		}
		else
			MLV_draw_text_with_font(temp->x+temp->padding, temp->y+temp->padding, temp->value, temp->font, colorText);
		
	}
}
void ButtonList_AnimButtons(ButtonList *lst)
{
	int i;
	for(i=0;i<lst->nb;i++)
		lst->tab[i]->anim=1;
}
void ButtonList_AffAll(ButtonList *lst)
{
	int i;
	for(i=0;i<lst->nb;i++)
	{
		Button_Aff(lst->tab[i]);
	}
	MLV_actualise_window();
}
int CaracInStr(char c, char str[])
{
	int i;
	for(i=0;i<strlen(str);i++)
	{
		if(str[i] == c)
			return i;
	}
	return -1;
}

PartieCharg charger_une_partie(void)
{
	
	PartieCharg temp;
	temp.jetons_coming = NULL;
	temp.jetons = NULL;
	temp.points = 0;
	sprintf(temp.pseudo, "Anonyme");

	char *chaine_file = MyFile_ChargFile();
	if(chaine_file == NULL)
		return temp;
	if(chaine_file != NULL)
	{
		FILE *f = fopen(chaine_file, "r");
		if(f != NULL)
		{
			char c;
			int i=0;
			int forme = -1;
			int couleur = -1;
			int ligne = 1;
			TokenList *jetons_coming = TokenList_Create();
			TokenList *jetons = TokenList_Create();
			while((c = fgetc(f)) != EOF && ligne <= 2)
			{
				if(c == '\n')
				{
					ligne++;
					i=0;
					if(ligne == 3)
						break;
				}
				else if(ligne == 1 || ligne == 2)
				{
					if(i%2 == 0)
					{
						if((forme = CaracInStr(c, "CRTDEH")) == -1)
						{
							TokenList_Free(&jetons_coming);
							TokenList_Free(&jetons);
							return temp;
						}
					}
					else
					{
						if((couleur = CaracInStr(c, "rvbjnw")) == -1 || forme == -1)
						{
							TokenList_Free(&jetons_coming);
							TokenList_Free(&jetons);
							return temp;
						}
						Token jeton;
						jeton.color = couleur;
						jeton.form = forme;
						if(ligne == 1)
							TokenList_AjouterToken_EnFin(jetons_coming, jeton);
						else if(ligne == 2)
							TokenList_AjouterToken_EnFin(jetons, jeton);
						couleur = -1;
						forme = -1;
					}
					i+=1;
				}
			}
			int a = fscanf(f, "%s", temp.pseudo);
			a = fscanf(f, "%d", &(temp.points));
			a = fscanf(f, "%d", &(temp.time));
			a += 1;
			temp.jetons_coming = jetons_coming;
			temp.jetons = jetons;
			fclose(f);
		}
	}
	return temp;
}
int Load_Partie(void)
{
	if(jeu->listejeton != NULL)
		TokenList_Free(&(jeu->listejeton));
	if(jeu->genjeton != NULL)
		TokenList_Free(&(jeu->genjeton));
	int ok = 1;
	jeu->is_loaded=0;
	PartieCharg temp = charger_une_partie();
	
	if(temp.jetons_coming == NULL || temp.jetons == NULL)
	{
		ok = 0;
		return Menu_Lancer();
	}
	jeu->genjeton = temp.jetons_coming;
	jeu->listejeton = temp.jetons;
	jeu->score = temp.points;
	jeu->party_time = temp.time;
	Jeu_Set_Game_Mode(Game_Mode_Anim);
	jeu->is_loaded = 1;
	sprintf(jeu->pseudo, "%s", temp.pseudo);
	Jeu_Play();
	if(jeu->score != 0)
		maj_score(jeu->pseudo, jeu->score);
	ok++;
	return Menu_Lancer();
	
}
int Sauv_Partie(void)
{
	sauvegarder_une_partie(jeu->genjeton, jeu->listejeton, jeu->pseudo, jeu->score, jeu->party_time);
	return -1;
}
int sauvegarder_une_partie(TokenList *jetons_coming, TokenList *jetons, const char pseudo[], int points, int time)
{
	if(jetons_coming == NULL || jetons == NULL)
		return 0;
	char *chaine = (char *)malloc(sizeof(char)*(jetons_coming->taille*2+jetons->taille*2+1000));
	sprintf(chaine, "%c", '\0');
	PlayedToken *cur = jetons_coming->head;
	char formes[6] = "CRTDEH";
	char couleurs[6] = "rvbjnw";
	while(cur != NULL)
	{
		sprintf(chaine, "%s%c%c", chaine,formes[cur->jeton.form], couleurs[cur->jeton.color]);
		cur = cur->next;
	}
	sprintf(chaine, "%s\n", chaine);
	cur = jetons->head;
	while(cur != NULL)
	{
		sprintf(chaine, "%s%c%c", chaine,formes[cur->jeton.form], couleurs[cur->jeton.color]);
		cur = cur->next;
	}
	sprintf(chaine, "%s\n", chaine);
	sprintf(chaine, "%s%s\n", chaine, pseudo);
	sprintf(chaine, "%s%d\n", chaine, points);
	sprintf(chaine, "%s%d", chaine, time);
	MyFile_SauvFile(chaine);
	
	free(chaine);
	return 1;
}
int classement(void)
{
	Menu_affFond(-1, -1, -1, -1);
	
	draw_text_center("media/sewer.ttf", "Classement", 65, 75);
	MLV_draw_filled_rectangle(35,50,SCREEN_WIDTH-70, SCREEN_HEIGHT-150, MLV_rgba(0,0,0,140));
	Score *classement = ouvrir_score();
	aff_scoreWindow(classement, 50, 150, MLV_COLOR_WHITE);
	sauv_score(&classement);


	ButtonList *lst = ButtonList_Init();
	MLV_Font *font = MLV_load_font("media/sewer.ttf", 40);
	ButtonList_AddButton(lst, SCREEN_WIDTH/2-150, SCREEN_HEIGHT-50, 5, "REINIT", font, classement_reinit);
	ButtonList_AddButton(lst, SCREEN_WIDTH/2+150, SCREEN_HEIGHT-50, 5, "RETOUR", font, Menu_Lancer);

	
	ButtonList_AffAll(lst);
	int c=1;
	while(c != -1)
		c = ButtonList_Event(lst);
	MLV_free_font(font);
	ButtonList_FreeAll(&lst);
	return -1;
}
int classement2(void)
{
	Menu_affFond(-1, -1, -1, -1);
	
	draw_text_center("media/sewer.ttf", "Classement", 65, 75);
	MLV_draw_filled_rectangle(35,50,SCREEN_WIDTH-70, SCREEN_HEIGHT-150, MLV_rgba(0,0,0,140));
	Score *classement = ouvrir_score();
	aff_scoreWindow(classement, 50, 150, MLV_COLOR_WHITE);
	sauv_score(&classement);


	ButtonList *lst = ButtonList_Init();
	MLV_Font *font = MLV_load_font("media/sewer.ttf", 40);
	ButtonList_AddButton(lst, SCREEN_WIDTH/2-150, SCREEN_HEIGHT-50, 5, "REINIT", font, classement_reinit);
	ButtonList_AddButton(lst, SCREEN_WIDTH/2+150, SCREEN_HEIGHT-50, 5, "RETOUR", font, retour_au_bureau);

	
	ButtonList_AffAll(lst);
	int c=1;
	while(c != -1)
		c = ButtonList_Event(lst);
	MLV_free_font(font);
	ButtonList_FreeAll(&lst);
	return -1;
}
int classement_reinit(void)
{
	reinit_score();
	classement();
	return -1;
}
MLV_Image *fleche_droite(int hover)
{
	MLV_Color color = MLV_COLOR_WHITE;
	if(hover == 0)
		color = MLV_rgba(200,200,200,255);
	MLV_Image *img = MLV_create_image(50,50);
	MLV_draw_filled_rectangle_on_image(0,0,50,50,MLV_rgba(15,15,15,255),img);
	{
		int x[3] = {0,50,0};
		int y[3] = {0,25,50};
		MLV_draw_filled_polygon_on_image(x,y,3,color,img);
	}
	return img;
}
MLV_Image *fleche_gauche(int hover)
{
	MLV_Color color = MLV_COLOR_WHITE;
		if(hover == 0)
			color = MLV_rgba(200,200,200,255);
	MLV_Image *img = MLV_create_image(50,50);
	MLV_draw_filled_rectangle_on_image(0,0,50,50,MLV_rgba(15,15,15,255),img);
	{
		int x[3] = {0,50,50};
		int y[3] = {25,0,50};
		MLV_draw_filled_polygon_on_image(x,y,3,color,img);
	}
	return img;
}

int options(void)
{
	ButtonList *lst = ButtonList_Init();
	MLV_Font *font = MLV_load_font("media/sewer.ttf", 60);
	ButtonList_AddButton(lst, SCREEN_WIDTH/2, 650, 5, "VALIDER", font, Menu_Lancer);
	ButtonList_AddButton(lst, SCREEN_WIDTH/2, SCREEN_HEIGHT-50, 5, "RETOUR AU MENU", font, Menu_Lancer);
	
	Menu_affFond(-1, -1, -1, -1);
	draw_titleMain("media/sewer.ttf", "THREE TO GO", 90, lst);
	MLV_draw_filled_rectangle(SCREEN_WIDTH/2-lst->max_width/2-80,233,lst->max_width+160,240+lst->nb*50+130,MLV_rgba(15,15,15,255));
	MLV_draw_rectangle(SCREEN_WIDTH/2-lst->max_width/2-80,98,lst->max_width+160,377+lst->nb*50+130,MLV_rgba(120,120,120,50));
	ButtonList_AffAll(lst);
	
	MLV_Font *font_h3 = MLV_load_font("media/monof55.ttf",  30);
	
	MLV_Image *gauche = fleche_gauche(0);
	MLV_Image *droite = fleche_droite(0);
	MLV_Image *gaucheH = fleche_gauche(1);
	MLV_Image *droiteH = fleche_droite(1);
	
	char tampon[20];
	
	MLV_draw_text_with_font(SCREEN_WIDTH/2-300, 270, "Largeur de l'écran", font_h3, MLV_COLOR_WHITE);
	MLV_draw_image(gauche, SCREEN_WIDTH/2-200, 320);
	MLV_draw_image(droite, SCREEN_WIDTH/2+200, 320);
	sprintf(tampon, "%d", jeu->width);
	MLV_draw_text_with_font(SCREEN_WIDTH/2,330,tampon, font_h3, MLV_COLOR_WHITE);
	
	MLV_draw_text_with_font(SCREEN_WIDTH/2-300, 400, "Hauteur de l'écran", font_h3, MLV_COLOR_WHITE);
	MLV_draw_image(gauche, SCREEN_WIDTH/2-200, 450);
	MLV_draw_image(droite, SCREEN_WIDTH/2+200, 450);
	sprintf(tampon, "%d", jeu->height);
	MLV_draw_text_with_font(SCREEN_WIDTH/2,460,tampon, font_h3, MLV_COLOR_WHITE);
	
	int fullscreen=0;
	int tempX = jeu->width;
	int tempY = jeu->height;
	MLV_draw_text_with_font(SCREEN_WIDTH/2-300, 530, "Plein écran ?", font_h3, MLV_COLOR_WHITE);
	MLV_draw_filled_rectangle(SCREEN_WIDTH/2-50, 537, 15, 15, MLV_COLOR_WHITE);
	MLV_draw_rectangle(SCREEN_WIDTH/2-51, 536, 17, 17, MLV_rgba(100,100,100,255));

	MLV_actualise_window();
	MLV_Mouse_button mouseButton;
	MLV_Event event = MLV_NONE;
	MLV_Button_state state;
	int mouse[2];
	int i;
	while(1)
	{
		event = MLV_get_event(NULL,NULL,NULL,NULL,NULL, &mouse[0], &mouse[1], &mouseButton, &state);
		if(event == MLV_MOUSE_BUTTON && mouseButton == MLV_BUTTON_LEFT && state == MLV_RELEASED)
		{
			if(mouse[1]>=320 && mouse[1]<=370)
			{
				if(mouse[0]>=SCREEN_WIDTH/2-200 && mouse[0]<=SCREEN_WIDTH/2-150) //1G
				{
					if(tempX-20<=800)
						tempX = 800;
					else
						tempX -= 20;
					sprintf(tampon, "%d", tempX);
					MLV_draw_filled_rectangle(SCREEN_WIDTH/2-5,329,100,30,MLV_rgba(15,15,15,255));
					MLV_draw_text_with_font(SCREEN_WIDTH/2,330,tampon, font_h3, MLV_COLOR_WHITE);
					MLV_actualise_window();
				}
				else if(mouse[0]>=SCREEN_WIDTH/2+200 && mouse[0]<=SCREEN_WIDTH/2+250) //1D
				{
					if(tempX+20>MLV_get_desktop_width())
						tempX = MLV_get_desktop_width();
					else
						tempX += 20;
					sprintf(tampon, "%d", tempX);
					MLV_draw_filled_rectangle(SCREEN_WIDTH/2-5,329,100,30,MLV_rgba(15,15,15,255));
					MLV_draw_text_with_font(SCREEN_WIDTH/2,330,tampon, font_h3, MLV_COLOR_WHITE);
					MLV_actualise_window();
				}
			}
			else if(mouse[1]>=450 && mouse[1]<=500)
			{
				if(mouse[0]>=SCREEN_WIDTH/2-200 && mouse[0]<=SCREEN_WIDTH/2-150) //2G
				{
					if(tempY-20<=800)
						tempY = 800;
					else
						tempY -= 20;
					sprintf(tampon, "%d", tempY);
					MLV_draw_filled_rectangle(SCREEN_WIDTH/2-5,459,100,30,MLV_rgba(15,15,15,255));
					MLV_draw_text_with_font(SCREEN_WIDTH/2,460,tampon, font_h3, MLV_COLOR_WHITE);
					MLV_actualise_window();
				}
				else if(mouse[0]>=SCREEN_WIDTH/2+200 && mouse[0]<=SCREEN_WIDTH/2+250) //2D
				{
					if(tempY+20>MLV_get_desktop_height())
						tempY = MLV_get_desktop_height();
					else
						tempY += 20;
					sprintf(tampon, "%d", tempY);
					MLV_draw_filled_rectangle(SCREEN_WIDTH/2-5,459,100,30,MLV_rgba(15,15,15,255));
					MLV_draw_text_with_font(SCREEN_WIDTH/2,460,tampon, font_h3, MLV_COLOR_WHITE);
					MLV_actualise_window();
				}
			}
		}
		if(event == MLV_MOUSE_BUTTON && mouseButton == MLV_BUTTON_LEFT && state == MLV_RELEASED)
		{
			if(mouse[0]>=lst->tab[0]->x && mouse[0]<=lst->tab[0]->x+lst->tab[1]->width && mouse[1]>=lst->tab[0]->y && mouse[1]<=lst->tab[0]->y+lst->tab[0]->height) // Valider
			{
				Jeu_Set_Screen_Dimensions(tempX, tempY);
				if(fullscreen)
					MLV_enable_full_screen();
				else
					MLV_disable_full_screen();
				return Menu_Lancer();
			}
			if(mouse[0]>=SCREEN_WIDTH/2-51 && mouse[0]<=SCREEN_WIDTH/2-51+17 && mouse[1]>=536 && mouse[1]<=536+17)
			{
				if(fullscreen == 1)
				{
					fullscreen = 0;
					MLV_draw_filled_rectangle(SCREEN_WIDTH/2-50, 537, 15, 15, MLV_COLOR_WHITE);
					MLV_draw_rectangle(SCREEN_WIDTH/2-51, 536, 17, 17, MLV_rgba(100,100,100,255));
					MLV_actualise_window();
				}
				else
				{
					fullscreen = 1;
					MLV_draw_filled_rectangle(SCREEN_WIDTH/2-50, 537, 15, 15, MLV_COLOR_WHITE);
					MLV_draw_rectangle(SCREEN_WIDTH/2-51, 536, 17, 17, MLV_rgba(100,100,100,255));
					MLV_draw_line(SCREEN_WIDTH/2-51, 536, SCREEN_WIDTH/2-51+17, 536+17, MLV_COLOR_BLACK);
					MLV_draw_line(SCREEN_WIDTH/2-51+17, 536, SCREEN_WIDTH/2-51, 536+17, MLV_COLOR_BLACK);
					MLV_actualise_window();
				}
			}
		}
		for(i=0;i<lst->nb;i++)
		{
			if(event == MLV_MOUSE_BUTTON && mouseButton == MLV_BUTTON_LEFT && state == MLV_RELEASED && (mouse[0]>=lst->tab[1]->x && mouse[0]<=lst->tab[1]->x+lst->tab[1]->width && mouse[1]>=lst->tab[1]->y && mouse[1]<=lst->tab[1]->y+lst->tab[1]->height)) // Clic sur le bouton
			{
				return lst->tab[1]->function();
			}
			if(event == MLV_MOUSE_MOTION && lst->tab[i]->hover && !(mouse[0]>=lst->tab[i]->x && mouse[0]<=lst->tab[i]->x+lst->tab[i]->width && mouse[1]>=lst->tab[i]->y && mouse[1]<=lst->tab[i]->y+lst->tab[i]->height)) // Bouton Sélectionné mais plus hover
			{
				lst->tab[i]->hover = 0;
				lst->tab[i]->borderActive = -1;
				Button_Aff(lst->tab[i]);
				MLV_actualise_window();
			
			}
			else if(event == MLV_MOUSE_MOTION && lst->tab[i]->hover == 0 && mouse[0]>=lst->tab[i]->x && mouse[0]<=lst->tab[i]->x+lst->tab[i]->width && mouse[1]>=lst->tab[i]->y && mouse[1]<=lst->tab[i]->y+lst->tab[i]->height) // Bouton non sélectionné mais hover
			{
				lst->tab[i]->hover = 1;
				Button_Aff(lst->tab[i]);
				MLV_actualise_window();
			}
			else if(lst->tab[i]->hover == 1 && event == MLV_NONE) // hover && sélectionné
			{
				lst->tab[i]->borderActive++;
				if(lst->tab[i]->borderActive == 4)
					lst->tab[i]->borderActive = 0;
				Button_Aff(lst->tab[i]);
				MLV_actualise_window();
			}
		}
	}
	MLV_free_image(gauche);
	MLV_free_image(droite);
	MLV_free_image(gaucheH);
	MLV_free_image(droiteH);
	MLV_free_font(font_h3);
	MLV_free_font(font);
	ButtonList_FreeAll(&lst);
	
	return -1;
}
MLV_Image *Create_ModeBasic(void)
{
	MLV_Image *img = MLV_create_image(100,100);
	MLV_draw_filled_rectangle_on_image(0,0,100,100,MLV_rgba(15,15,15,255), img);
	{
		int x[3] = {0,25,50};
		int y[3] = {50,0,50};
		MLV_draw_filled_polygon_on_image(x,y,3,MLV_COLOR_RED, img);
	}
	MLV_draw_filled_rectangle_on_image(50,0,50,50,MLV_COLOR_GREEN, img);
	MLV_draw_filled_circle_on_image(25,75,25,MLV_COLOR_BLUE,img);
	{
		int tx[10];
		int ty[10];
		int i;
		for(i = 0; i < 5; i ++)
		{
			tx[2*i] = 75+((50/2)*cos(radian_convert((i*72)-90)));
			ty[2*i] = 75+((50/2)*sin(radian_convert((i*72)-90)));
		}
		for(i = 0; i < 5; i ++)
		{
			tx[(2*i)+1] = 75+((50/4)*cos(radian_convert((i*72)+36-90)));
			ty[(2*i)+1] = 75+((50/4)*sin(radian_convert((i*72)+36-90)));
		}
		MLV_draw_filled_polygon_on_image(tx, ty, 10, MLV_COLOR_YELLOW, img);
	}
	return img;
}
MLV_Image *Create_ModeAnim(void)
{
	MLV_Image *img = MLV_create_image(100,100);
	MLV_draw_filled_rectangle_on_image(0,0,100,100,MLV_rgba(15,15,15,255), img);
	
	MLV_draw_image_on_image(MLV_Image_Create_Triangle(MLV_COLOR_RED, 50), img,0,0);
	MLV_draw_image_on_image(MLV_Image_Create_Carre(MLV_COLOR_GREEN, 50), img,50,0);
	MLV_draw_image_on_image(MLV_Image_Create_Cercle(MLV_COLOR_BLUE, 50), img,0,50);
	MLV_draw_image_on_image(MLV_Image_Create_Etoile(MLV_COLOR_YELLOW, 50), img,50,50);
	
	return img;
}
MLV_Image *MLV_Image_Difficulty_Button(Difficulty dif, int width, int height)
{
	MLV_Color couleur;
	MLV_Image *jeton = NULL;
	switch(dif)
	{
		case TUTO:
		couleur = MLV_rgba(40, 108, 221, 255);
		jeton = MLV_Image_Create_Carre(Get_MLV_Color(dif-1), min(width, height)/2);
		break;
		case FACILE:
		couleur = MLV_rgba(31, 175, 52, 255);
		jeton = MLV_Image_Create_Losange(Get_MLV_Color(dif-1), min(width, height)/2);
		break;
		case INTERMEDIAIRE:
		couleur = MLV_rgba(236, 173, 13, 255);
		jeton = MLV_Image_Create_Etoile(Get_MLV_Color(dif-1), min(width, height)/2);
		break;
		case EXPERT:
		couleur = MLV_rgba(175, 31, 31, 255);
		jeton = MLV_Image_Create_Hexagone(Get_MLV_Color(dif-1), min(width, height)/2);
		break;
		default:
		couleur = MLV_rgba(127, 127, 127, 255);
		break;
	}
	MLV_Image *image = MLV_create_image(width, height);
	MLV_draw_filled_rectangle_on_image(0, 0, width, height, couleur, image);
	MLV_draw_image_on_image(jeton, image, width/2-MLV_get_image_width(jeton)/2, height/2-MLV_get_image_height(jeton)/2);
	MLV_free_image(jeton);
	return image;
}
int jouer(void)
{
	ButtonList *lst = ButtonList_Init();
	MLV_Font *font = MLV_load_font("media/sewer.ttf", 60);
	ButtonList_AddButton(lst, SCREEN_WIDTH/2, 720, 5, "JOUER", font, Menu_Lancer);
	ButtonList_AddButton(lst, SCREEN_WIDTH/2, SCREEN_HEIGHT-50, 5, "RETOUR AU MENU", font, Menu_Lancer);
	
	lst->tab[0]->anim=1;
	
	Jeu_Set_Difficulty(TUTO);
	int diff = 0;
	// Affichages
	Menu_affFond(-1, -1, -1, -1);
	draw_titleMain("media/sewer.ttf", "THREE TO GO", 90, lst);
	MLV_draw_filled_rectangle(SCREEN_WIDTH/2-lst->max_width/2-80,233,lst->max_width+160,240+lst->nb*50+180,MLV_rgba(15,15,15,255));
	MLV_draw_rectangle(SCREEN_WIDTH/2-lst->max_width/2-80,98,lst->max_width+160,377+lst->nb*50+180,MLV_rgba(120,120,120,50));
	ButtonList_AffAll(lst);
	
	MLV_Font *font_h3 = MLV_load_font("media/monof55.ttf",  35);
	MLV_draw_text_with_font(SCREEN_WIDTH/2-300, 350, "Modes d'Affichages", font_h3, MLV_COLOR_WHITE);
	MLV_draw_text_with_font(SCREEN_WIDTH/2-300, 550, "Difficultée", font_h3, MLV_COLOR_WHITE);
	
	MLV_Font *pseudo = MLV_load_font("media/monof55.ttf", 20);
	
	MLV_Image *basic = Create_ModeBasic();
	MLV_Image *anim = Create_ModeAnim();
	
	MLV_draw_image(basic, SCREEN_WIDTH/2-200, 400);
	MLV_draw_image(anim, SCREEN_WIDTH/2-50, 400);
	
	MLV_draw_text_with_font(SCREEN_WIDTH/2-175, 510, "Basic", pseudo, MLV_COLOR_WHITE);
	MLV_draw_text_with_font(SCREEN_WIDTH/2-25, 510, "Animé", pseudo, MLV_COLOR_WHITE);
	
	MLV_Image *tuto = MLV_Image_Difficulty_Button(TUTO,75,75);
	MLV_Image *facile = MLV_Image_Difficulty_Button(FACILE, 75,75);
	MLV_Image *intermediaire = MLV_Image_Difficulty_Button(INTERMEDIAIRE,75,75);
	MLV_Image *expert = MLV_Image_Difficulty_Button(EXPERT,75,75);
	
	MLV_draw_filled_rectangle(SCREEN_WIDTH/2-252,588,79,79,MLV_COLOR_WHITE);
	
	MLV_draw_image(tuto, SCREEN_WIDTH/2-250, 590);
	MLV_draw_image(facile, SCREEN_WIDTH/2-100, 590);
	MLV_draw_image(intermediaire, SCREEN_WIDTH/2+50, 590);
	MLV_draw_image(expert, SCREEN_WIDTH/2+200, 590);
	
	
	
	MLV_free_image(basic);
	MLV_free_image(anim);

	
	Jeu_Set_Game_Mode(Game_Mode_Base);
	
	if(jeu->game_mode == Game_Mode_Base)
	{
		MLV_draw_rectangle(SCREEN_WIDTH/2-201, 399,102,102,MLV_COLOR_WHITE);
		MLV_draw_rectangle(SCREEN_WIDTH/2-202, 398,104,104,MLV_COLOR_WHITE);
	}
	else if(jeu ->game_mode == Game_Mode_Anim)
	{
		MLV_draw_rectangle(SCREEN_WIDTH/2-49, 399,102,102,MLV_COLOR_WHITE);
		MLV_draw_rectangle(SCREEN_WIDTH/2-48, 398,104,104,MLV_COLOR_WHITE);
	}			


	MLV_Input_box *input_box_2 = MLV_create_input_box(SCREEN_WIDTH/2-200, 250, lst->max_width-100, 50, MLV_rgba(120,120,120, 255), MLV_COLOR_WHITE, MLV_rgba(0,0,0,255), "Pseudo : ");
	

	//MLV_draw_text_with_font(SCREEN_WIDTH/2-300, 550, "Tuto ?", pseudo, MLV_COLOR_WHITE);
	char pseudo_affich[240];
	
	MLV_draw_all_input_boxes();
	MLV_actualise_window();
	
	MLV_Input_box *temp_box;
	char *texte = NULL, *final_text = NULL;
	MLV_Event event2 = MLV_NONE;;

	
	int c=1;
	while(c != -1)
	{
		event2 = MLV_get_event(NULL, NULL, NULL,&texte, &temp_box,NULL, NULL, NULL,NULL);
		if(event2 == MLV_INPUT_BOX)
		{
			final_text = texte;
			sprintf(pseudo_affich, "Pseudo Choisi : %s", final_text);
			MLV_draw_filled_rectangle(SCREEN_WIDTH/2-201, 249, lst->max_width-90, 52, MLV_rgba(15,15,15,255));
			MLV_draw_text_with_font(SCREEN_WIDTH/2-300,310,pseudo_affich, pseudo, MLV_COLOR_WHITE);
			MLV_desactivate_input_box(input_box_2);
			MLV_actualise_window();
			break;
		}
		MLV_draw_input_box(input_box_2);
		MLV_actualise_window();
	}
	char pseudoChoisi[100] = "";
	if(final_text != NULL)
	{
		sprintf(pseudoChoisi, "%s", final_text);
		free(final_text);
	}
	else
	{
		sprintf(pseudoChoisi, "Anonyme");
	}
	MLV_free_input_box(input_box_2);
	MLV_Mouse_button mouseButton;
	MLV_Event event = MLV_NONE;
	MLV_Button_state state;
	int mouse[2];
	
	while(1)
	{
		event = MLV_get_event(NULL,NULL,NULL,NULL,NULL, &mouse[0], &mouse[1], &mouseButton, &state);
		if(event == MLV_MOUSE_BUTTON && mouseButton == MLV_BUTTON_LEFT && state == MLV_RELEASED)
		{
			if(mouse[1]>=400 && mouse[1]<=500)
			{
				if(mouse[0]>=SCREEN_WIDTH/2-200 && mouse[0]<=SCREEN_WIDTH/2-100)
				{
					if(jeu->game_mode != Game_Mode_Base)
					{
						Jeu_Set_Game_Mode(Game_Mode_Base);
						MLV_draw_rectangle(SCREEN_WIDTH/2-49, 399,102,102,MLV_rgba(15,15,15,255));
						MLV_draw_rectangle(SCREEN_WIDTH/2-48, 398,104,104,MLV_rgba(15,15,15,255));
						MLV_draw_rectangle(SCREEN_WIDTH/2+99, 399, 102, 102, MLV_rgba(15,15,15,255));
						MLV_draw_rectangle(SCREEN_WIDTH/2+98, 398, 104, 104, MLV_rgba(15,15,15,255));
						
						MLV_draw_rectangle(SCREEN_WIDTH/2-201, 399,102,102,MLV_COLOR_WHITE);
						MLV_draw_rectangle(SCREEN_WIDTH/2-202, 398,104,104,MLV_COLOR_WHITE);
						MLV_actualise_window();
					}
				}
				else if(mouse[0]>=SCREEN_WIDTH/2-50 && mouse[0]<=SCREEN_WIDTH/2+50)
				{
					if(jeu->game_mode != Game_Mode_Anim)
					{
						Jeu_Set_Game_Mode(Game_Mode_Anim);
						MLV_draw_rectangle(SCREEN_WIDTH/2-201, 399,102,102,MLV_rgba(15,15,15,255));
						MLV_draw_rectangle(SCREEN_WIDTH/2-202, 398,104,104,MLV_rgba(15,15,15,255));
						MLV_draw_rectangle(SCREEN_WIDTH/2+99, 399, 102, 102, MLV_rgba(15,15,15,255));
						MLV_draw_rectangle(SCREEN_WIDTH/2+98, 398, 104, 104, MLV_rgba(15,15,15,255));
						
						MLV_draw_rectangle(SCREEN_WIDTH/2-49, 399,102,102,MLV_COLOR_WHITE);
						MLV_draw_rectangle(SCREEN_WIDTH/2-48, 398,104,104,MLV_COLOR_WHITE);
						MLV_actualise_window();
					}
				}
			}

			if(mouse[1] >= 590 && mouse[1]<=590+75)
			{
				if(mouse[0]>=SCREEN_WIDTH/2-250 && mouse[0]<=SCREEN_WIDTH/2-250+75)
				{
					if(diff != 0)
					{
						Jeu_Set_Difficulty(TUTO);
						MLV_draw_filled_rectangle(SCREEN_WIDTH/2-252,588,79,79,MLV_COLOR_WHITE);
						MLV_draw_filled_rectangle(SCREEN_WIDTH/2-102,588,79,79,MLV_COLOR_BLACK);
						MLV_draw_filled_rectangle(SCREEN_WIDTH/2+48,588,79,79,MLV_COLOR_BLACK);
						MLV_draw_filled_rectangle(SCREEN_WIDTH/2+198,588,79,79,MLV_COLOR_BLACK);
						jeu->is_tuto=1;
						diff = 0;
					}
				}
				else if(mouse[0]>=SCREEN_WIDTH/2-100 && mouse[0]<=SCREEN_WIDTH/2-100+75)
				{
					if(diff != 1)
					{
						Jeu_Set_Difficulty(FACILE);
						MLV_draw_filled_rectangle(SCREEN_WIDTH/2-252,588,79,79,MLV_COLOR_BLACK);
						MLV_draw_filled_rectangle(SCREEN_WIDTH/2-102,588,79,79,MLV_COLOR_WHITE);
						MLV_draw_filled_rectangle(SCREEN_WIDTH/2+48,588,79,79,MLV_COLOR_BLACK);
						MLV_draw_filled_rectangle(SCREEN_WIDTH/2+198,588,79,79,MLV_COLOR_BLACK);
						jeu->is_tuto=0;
						diff = 1;
					}
				}
				else if(mouse[0]>=SCREEN_WIDTH/2+50 && mouse[0]<=SCREEN_WIDTH/2+50+75)
				{
					if(diff != 2)
					{
						Jeu_Set_Difficulty(INTERMEDIAIRE);
						MLV_draw_filled_rectangle(SCREEN_WIDTH/2-252,588,79,79,MLV_COLOR_BLACK);
						MLV_draw_filled_rectangle(SCREEN_WIDTH/2-102,588,79,79,MLV_COLOR_BLACK);
						MLV_draw_filled_rectangle(SCREEN_WIDTH/2+48,588,79,79,MLV_COLOR_WHITE);
						MLV_draw_filled_rectangle(SCREEN_WIDTH/2+198,588,79,79,MLV_COLOR_BLACK);
						jeu->is_tuto=0;
						diff = 2;
					}
				}
				else if(mouse[0]>=SCREEN_WIDTH/2+200 && mouse[0]<=SCREEN_WIDTH/2+200+75)
				{
					if(diff != 3)
					{
						Jeu_Set_Difficulty(EXPERT);
						MLV_draw_filled_rectangle(SCREEN_WIDTH/2-252,588,79,79,MLV_COLOR_BLACK);
						MLV_draw_filled_rectangle(SCREEN_WIDTH/2-102,588,79,79,MLV_COLOR_BLACK);
						MLV_draw_filled_rectangle(SCREEN_WIDTH/2+48,588,79,79,MLV_COLOR_BLACK);
						MLV_draw_filled_rectangle(SCREEN_WIDTH/2+198,588,79,79,MLV_COLOR_WHITE);
						jeu->is_tuto=0;
						diff=3;
					}
				}
				MLV_draw_image(tuto, SCREEN_WIDTH/2-250, 590);
				MLV_draw_image(facile, SCREEN_WIDTH/2-100, 590);
				MLV_draw_image(intermediaire, SCREEN_WIDTH/2+50, 590);
				MLV_draw_image(expert, SCREEN_WIDTH/2+200, 590);
				MLV_actualise_window();
			}
		}
		if(event == MLV_MOUSE_BUTTON && mouseButton == MLV_BUTTON_LEFT && state == MLV_RELEASED && (mouse[0]>=lst->tab[0]->x && mouse[0]<=lst->tab[0]->x+lst->tab[0]->width && mouse[1]>=lst->tab[0]->y && mouse[1]<=lst->tab[0]->y+lst->tab[0]->height)) // Clic Bouton Jouer
		{
			sprintf(jeu->pseudo, "%s", pseudoChoisi);
			Jeu_Play();
			if(jeu->score != 0)
				maj_score(jeu->pseudo, jeu->score);
			return Menu_Lancer();
		}
		else if(event == MLV_MOUSE_BUTTON && mouseButton == MLV_BUTTON_LEFT && state == MLV_RELEASED && (mouse[0]>=lst->tab[1]->x && mouse[0]<=lst->tab[1]->x+lst->tab[1]->width && mouse[1]>=lst->tab[1]->y && mouse[1]<=lst->tab[1]->y+lst->tab[1]->height)) // Clic Bouton Retour
		{
			return lst->tab[1]->function();
		}
		int i;
		for(i=0;i<2;i++)
		{
			if(event == MLV_MOUSE_MOTION && lst->tab[i]->hover && !(mouse[0]>=lst->tab[i]->x && mouse[0]<=lst->tab[i]->x+lst->tab[i]->width && mouse[1]>=lst->tab[i]->y && mouse[1]<=lst->tab[i]->y+lst->tab[i]->height)) // Bouton Sélectionné mais plus hover
			{
				lst->tab[i]->hover = 0;
				lst->tab[i]->borderActive = -1;
				Button_Aff(lst->tab[i]);
				MLV_actualise_window();
			
			}
			else if(event == MLV_MOUSE_MOTION && lst->tab[i]->hover == 0 && mouse[0]>=lst->tab[i]->x && mouse[0]<=lst->tab[i]->x+lst->tab[i]->width && mouse[1]>=lst->tab[i]->y && mouse[1]<=lst->tab[i]->y+lst->tab[i]->height) // Bouton non sélectionné mais hover
			{
				lst->tab[i]->hover = 1;
				Button_Aff(lst->tab[i]);
				MLV_actualise_window();
			}
			else if(lst->tab[i]->hover == 1 && event == MLV_NONE) // hover && sélectionné
			{
				lst->tab[i]->borderActive++;
				if(lst->tab[i]->borderActive == 4)
					lst->tab[i]->borderActive = 0;
				Button_Aff(lst->tab[i]);
				MLV_actualise_window();
			}
		}
	}
	MLV_free_image(tuto);
	MLV_free_image(intermediaire);
	MLV_free_image(facile);
	MLV_free_image(expert);
	
	MLV_free_font(pseudo);
	MLV_free_font(font);
	MLV_free_font(font_h3);
	
	ButtonList_FreeAll(&lst);
	

	return -1;
}
int retour_au_bureau(void)
{
	return -1;
}
int ButtonList_Event(ButtonList *lst)
{
	int mouse[2] = {0};
	MLV_Keyboard_button sym = MLV_KEYBOARD_NONE;
	MLV_Mouse_button mouseButton;
	MLV_Event event = MLV_NONE;
	MLV_Button_state state;
	event = MLV_get_event(&sym,NULL,NULL,NULL,NULL, &mouse[0], &mouse[1], &mouseButton, &state);

	if(event == MLV_KEY && sym == MLV_KEYBOARD_ESCAPE)
		return 0;
	else if(event == MLV_KEY)
		return 0;
	int i;
	for(i=0;i<lst->nb;i++)
	{
		if(event == MLV_MOUSE_BUTTON && mouseButton == MLV_BUTTON_LEFT && state == MLV_RELEASED && (mouse[0]>=lst->tab[i]->x && mouse[0]<=lst->tab[i]->x+lst->tab[i]->width && mouse[1]>=lst->tab[i]->y && mouse[1]<=lst->tab[i]->y+lst->tab[i]->height)) // Clic sur le bouton
		{
			return lst->tab[i]->function();
		}
		if(event == MLV_MOUSE_MOTION && lst->tab[i]->hover && !(mouse[0]>=lst->tab[i]->x && mouse[0]<=lst->tab[i]->x+lst->tab[i]->width && mouse[1]>=lst->tab[i]->y && mouse[1]<=lst->tab[i]->y+lst->tab[i]->height)) // Bouton Sélectionné mais plus hover
		{
			lst->tab[i]->hover = 0;
			lst->tab[i]->borderActive = -1;
			Button_Aff(lst->tab[i]);
			MLV_actualise_window();
			
		}
		else if(event == MLV_MOUSE_MOTION && lst->tab[i]->hover == 0 && mouse[0]>=lst->tab[i]->x && mouse[0]<=lst->tab[i]->x+lst->tab[i]->width && mouse[1]>=lst->tab[i]->y && mouse[1]<=lst->tab[i]->y+lst->tab[i]->height) // Bouton non sélectionné mais hover
		{
			lst->tab[i]->hover = 1;
			Button_Aff(lst->tab[i]);
			MLV_actualise_window();
		}
		else if(lst->tab[i]->hover == 1 && event == MLV_NONE) // hover && sélectionné
		{
			lst->tab[i]->borderActive++;
			if(lst->tab[i]->borderActive == 4)
				lst->tab[i]->borderActive = 0;
			Button_Aff(lst->tab[i]);
			MLV_actualise_window();
		}
	}
	return 1;
	
}
void draw_titleMain(const char font_str[], const char title[], int taille, ButtonList *lst)
{
	MLV_Font *font = MLV_load_font(font_str, taille);
	int width,height;
	MLV_get_size_of_adapted_text_box_with_font((char *)title, font, 0, &(width), &(height));
	MLV_draw_filled_rectangle(SCREEN_WIDTH/2-lst->max_width/2-80,100,lst->max_width+160,130,MLV_rgba(15,15,15,255));
	MLV_draw_filled_rectangle(SCREEN_WIDTH/2-lst->max_width/2-80,130+height-5,lst->max_width+160,5,MLV_rgba(50,50,50,255));
	MLV_draw_filled_rectangle(SCREEN_WIDTH/2-lst->max_width/2-80,130+height,lst->max_width+160,1,MLV_rgba(70,70,70,255));
	MLV_draw_text_with_font(SCREEN_WIDTH/2-width/2, 130, (char *)title, font, MLV_COLOR_WHITE);
	MLV_free_font(font);
}
void draw_text_center(const char font_str[], const char title[], int taille, int h)
{
	MLV_Font *font = MLV_load_font(font_str, taille);
	int width,height;
	MLV_get_size_of_adapted_text_box_with_font((char *)title, font, 0, &(width), &(height));
	MLV_draw_text_with_font(SCREEN_WIDTH/2-width/2, h, (char *)title, font, MLV_COLOR_WHITE);
	MLV_free_font(font);
}

MLV_Image *Menu_ConstrucFond(int seed, int type)
{
	MLV_Image *fond = MLV_create_image(50,50);
	if(fond == NULL)
		return NULL;
	srand(time(NULL)+seed);
	
	MLV_Color colorsFond[3] ={MLV_rgba(100,100,100,255), MLV_rgba(19,19,19,200), MLV_rgba(30,30,30,255)};
	MLV_draw_line_on_image(0,0,30,30,colorsFond[2], fond);
	MLV_draw_line_on_image(20,20,50,50,colorsFond[2], fond);
	MLV_draw_line_on_image(20,20,50,0,colorsFond[2], fond);
	MLV_draw_line_on_image(20,20,0,50,colorsFond[2], fond);
	
	MLV_draw_line_on_image(1,0,31,30,colorsFond[1], fond);
	MLV_draw_line_on_image(31,30,51,50,colorsFond[1], fond);
	MLV_draw_line_on_image(23,20,49,0,colorsFond[1], fond);
	MLV_draw_line_on_image(20,29,0,49,colorsFond[1], fond);
	if(type)
	{
		if(rand()%100<=70)
			return fond;
		int fig=rand()%6;
		MLV_Color figColor = MLV_rgba(10+rand()%50,10+rand()%50,10+rand()%50,255);
		if(fig == 0)
			MLV_draw_image_on_image(MLV_Image_Create_Cercle(figColor, 40), fond,5,5);
		else if(fig == 1)
			MLV_draw_image_on_image(MLV_Image_Create_Triangle(figColor, 40), fond,2,2);
		else if(fig == 2)
			MLV_draw_image_on_image(MLV_Image_Create_Carre(figColor, 40), fond,5,5);
		else if(fig == 3)
			MLV_draw_image_on_image(MLV_Image_Create_Losange(figColor, 40), fond,2,2);
		else if(fig == 4)
			MLV_draw_image_on_image(MLV_Image_Create_Etoile(figColor, 40), fond,2,2);
		else if(fig == 5)
			MLV_draw_image_on_image(MLV_Image_Create_Hexagone(figColor, 40), fond,5,5);
	}
	return fond;
}
void Menu_affFond(int baseX, int baseY, int maxX, int maxY)
{
	if(baseX == -1)
		baseX = 0;
	if(baseY == -1)
		baseY = 0;
	if(maxX == -1)
		maxX = SCREEN_WIDTH;
	if(maxY == -1)
		maxY = SCREEN_HEIGHT;
	int x=baseX,y=baseY;
	while(x<maxX)
	{
		y=baseY;
		while(y<maxY)
		{
			MLV_Image *fond = NULL;
			if(x+150>=maxX && y+150>=maxY)
				fond = Menu_ConstrucFond(x*x+y, 0);
			else
				fond = Menu_ConstrucFond(x*x+x*y+y*y*y, 1);
			MLV_draw_image(fond, x, y);
			MLV_free_image(fond);
			y+=50;
		}
		x+=50;
	}
	MLV_actualise_window();
}
void Menu_AffVersion(void)
{
	MLV_Font *ft_version = MLV_load_font("media/monof55.ttf", 15);
	char version[25];
	int w,h;
	sprintf(version, "Version %g", (double)VERSION);
	MLV_get_size_of_adapted_text_box_with_font(version, ft_version, 0, &w, &h);
	MLV_draw_text_with_font(SCREEN_WIDTH-w-5, SCREEN_HEIGHT-20, version, ft_version, MLV_COLOR_WHITE);
	MLV_free_font(ft_version);
}
int Jeu_Edit_Avatar(void)
{
	Avatar_Gest(jeu->avatar);
	Jeu_Set_Screen_Dimensions(WIDTH, HEIGHT);
	return Menu_Lancer();
}

int Menu_Lancer(void)
{
	ButtonList *lst = ButtonList_Init();
	MLV_Font *font = MLV_load_font("media/sewer.ttf", 60);
	ButtonList_AddButton(lst, SCREEN_WIDTH/2, 300, 5, "JOUER", font, jouer);
	ButtonList_AddButton(lst, SCREEN_WIDTH/2, 390, 5, "CHARGER", font, Load_Partie);
	ButtonList_AddButton(lst, SCREEN_WIDTH/2, 480, 5, "OPTIONS", font, options);
	ButtonList_AddButton(lst, SCREEN_WIDTH/2, 570, 5, "CLASSEMENT", font, classement);
	ButtonList_AddButton(lst, SCREEN_WIDTH/2, 660, 5, "AVATARS", font, Jeu_Edit_Avatar);
	ButtonList_AddButton(lst, SCREEN_WIDTH/2, 750, 5, "RETOUR AU BUREAU", font, retour_au_bureau);
	
	// Affichages
	ButtonList_AnimButtons(lst);
	Menu_affFond(-1, -1, -1, -1);
	draw_titleMain("media/sewer.ttf", "THREE TO GO", 90, lst);
	Menu_AffVersion();
	MLV_draw_filled_rectangle(SCREEN_WIDTH/2-lst->max_width/2-80,233,lst->max_width+160,240+lst->nb*55,MLV_rgba(15,15,15,255));
	MLV_draw_rectangle(SCREEN_WIDTH/2-lst->max_width/2-80,98,lst->max_width+160,377+lst->nb*55,MLV_rgba(120,120,120,50));
	ButtonList_AffAll(lst);
	
	int c=1;
	while(c != -1)
		c = ButtonList_Event(lst);
	MLV_free_font(font);
	ButtonList_FreeAll(&lst);
	
	return -1;
}

