#include "score.h"

/************ LOCAL FUNCTIONS *********/
Score *dev_AllocScore(const char str[], int points)
{
	Score *temp = (Score *)malloc(sizeof(Score));
	if(temp == NULL)
		return NULL;
	temp->nom = (char *)malloc((strlen(str)+1)*sizeof(char));
	if(temp->nom == NULL)
		return NULL;
	strcpy(temp->nom, str);
	temp->points = points;
	temp->suivant = NULL;
	return temp;
}
void score_AllocFree(Score *score)
{
	if(score != NULL)
	{
		score_AllocFree(score->suivant);
		free(score->nom);
		free(score);	
	}
}
void score_Free(Score **score)
{
	score_AllocFree(*score);
	*score = NULL;
}


/*** NORMAL FUNCTIONS ****/
void reinit_score(void)
{
	FILE *f = fopen(SCORE_FILE, "w");
	fclose(f);
}
Score *ouvrir_score(void)
{
	FILE *f = fopen(SCORE_FILE, "r");
	if(f == NULL)
		return NULL;
	char chaine[1000];
	int pt=-1;
	Score *lst = NULL;
	Score *sauv = NULL;
	while(fscanf(f, "%s - %d", chaine, &pt) == 2)
	{
		if(pt!=-1)
		{
			Score *temp = dev_AllocScore(chaine, pt);
			if(lst == NULL)
			{
				lst = temp;
				sauv = temp;
			}
			else
			{
				lst->suivant = temp;
				lst = lst->suivant;
			}
			pt=-1;
		}
	}
	fclose(f);
	return sauv;
}
int sauv_score(Score **score)
{
	if(score == NULL || *score == NULL)
		return 0;
	FILE *f = fopen(SCORE_FILE, "w");
	if(f == NULL)
		return 0;
	Score *cur = *score;
	while(cur != NULL)
	{
		fprintf(f, "%s - %d\n", cur->nom, cur->points);
		cur = cur->suivant;
	}
	fclose(f);
	score_Free(score);
	return 1;
}
int insere_score(Score **lst, const char nom[], int points)
{
	Score *temp = dev_AllocScore(nom, points);
	if(*lst == NULL)
	{
		*lst = temp;
		return 1;
	}
	Score *cur = *lst;
	if(cur->points < points)
	{
		temp->suivant = *lst;
		*lst = temp;
		return 1;
	}
	while(cur->suivant != NULL && cur->suivant->points > points)
		cur = cur->suivant;
	if(cur->suivant == NULL)
		cur->suivant = temp;
	else
	{
		temp->suivant = cur->suivant;
		cur->suivant=temp;
	}
	return 1;
}
int maj_score(const char nom[], int points)
{
	Score *temp = ouvrir_score();
	if(insere_score(&temp, nom, points) == 0)
		return 0;
	if(sauv_score(&temp) == 0)
		return 0;
	return 1;
}


/*** AFFICHAGES SCORES ******/
void aff_scoreWindow(Score *score, int base_x, int base_y, MLV_Color color)
{
	MLV_Font *font = MLV_load_font("media/monof55.ttf", 28);
	int i=1;
	int max_nb = (int)((SCREEN_HEIGHT-200)/42.0);
	if(score == NULL)
	{
		draw_text_center("media/monof55.ttf", "Aucun score enregistré ...", 37, SCREEN_HEIGHT/2);
	}
	while(score != NULL && i<max_nb)
	{
		char *chaine = (char *)malloc(sizeof(char)*40);
		sprintf(chaine, "%d - %s", i, score->nom);
		char *chaine_score = (char *)malloc(sizeof(char)*15);
		sprintf(chaine_score, "%d point%s", score->points, (score->points>1)?"s":"");
		MLV_draw_text_with_font(base_x, base_y+(i-1)*42, chaine, font, color);
		MLV_draw_text_with_font(MLV_get_window_width()-strlen(chaine_score)*14-50, base_y+(i-1)*42, chaine_score, font, color);
		if(score->suivant != NULL && i+1<max_nb)
		{
			MLV_draw_line(base_x-10, base_y+i*42-5, MLV_get_window_width()-40, base_y+i*42-5, color);
		}
		free(chaine);
		free(chaine_score);
		i++;
		score = score->suivant;
	}
	MLV_free_font(font);
	MLV_actualise_window();
}
void aff_scoreConsole(Score *score)
{
	int i=1;
	while(score != NULL)
	{
		printf("n°%d - %s (%d point%s) \n", i, score->nom, score->points, (score->points>1)?"s":"");
		score = score->suivant;
		i++;
	}
}

