#ifndef HEAD_SCORE
#define HEAD_SCORE

#define SCORE_FILE "media/classement.txt"

#include "menu.h"

/* Structure qui permet de tenir un classement en listes chainées ordonnées des meilleurs scores associés à un nom. 
(Le premier dans la liste est le meilleur)
*/
typedef struct Score Score;
struct Score
{
	char *nom;
	int points;
	Score *suivant;
};


/* Fonction 'locales' */
Score *dev_AllocScore(const char nom[], int points);
/*
	Permet d'allouer une structure score en donnant un nom et un score
	ARGS :
		- const char nom[] : Une chaîne de caractère (Pseudo)
		- int points : Score
	RETURN :
		- NULL si échec
		- Structure Score si réussi
*/

/* Fonctions Permettant de free les structures Scores */
void score_AllocFree(Score *score);
void score_Free(Score **score);


void reinit_score(void);
/*
	Reinitialise le fichier des scores defini par #define SCORE_FILE $$$
*/


Score *ouvrir_score(void);
/*
	Ouvrir le fichier des scores et charge son contenu dans une liste chainée de Score.
	RETURN :
		- NULL si échec
		- Première structure Score * de la liste chainée
*/


int insere_score(Score **lst, const char nom[], int points);
/*
	Insère un nouveau score dans la liste chainée *lst tout en conservant sa monotonie.
	ARGS :
		- Score **lst : Structure Score à modifier
		- const char nom[] : Pseudo
		- int points : Score
	RETURN :
		- 0 si échec
		- 1 si réussi
*/


int sauv_score(Score **score);
/*
	Sauvegarde les scores contenu dans score dans le fichier des scores ET free/libère la liste chainée score.
	ARGS :
		- Score **score : Liste chainée des Scores
	RETURN :
		- 0 si échec
		- 1 si réussi
*/

int maj_score(const char name[], int score);
/*
	Met à jour le fichier des scores avec un nouveau score
	ARGS :
		- const char nom[] : Pseudo
		- int points : Score
	RETURN :
		- 0 si échec
		- 1 si réussi
*/


// Affichages
void aff_scoreConsole(Score *score);
/*
	Affichage rudimentaire de la liste chainée des scores en console
	ARGS :
		- Score *score : Liste chainée des Scores
*/


void aff_scoreWindow(Score *score, int base_x, int base_y, MLV_Color color);
/*
	Affichage de la liste chainée des scores dans une fenêtre graphique (MLV)
	ARGS :
		- Score *score : Liste Chainée des Scores
		- int base_x : La position en X à partir de laquelle afficher le classement
		- int base_y : La position en Y à partir de laquelle afficher le classement.
		- MLV_Color color : Couleur du Texte
*/
#endif
