#ifndef DEF_HEADER_STRUCT_DATA
#define DEF_HEADER_STRUCT_DATA

/*
Header contenant les prototypes des structures
*/

#include <MLV/MLV_all.h>
#include <time.h>
#include <math.h>
#include "annexe.h"
#include "avatar_affichage.h"
#include "avatar_calcul.h"
#include "avatar_resize.h"

#define CAPTION "Projet L2 C - Kevin Trancho - Victor Veillerette - 2015"

#define LISTE_LIMITE 16

#define JETON_SIZE (((jeu->width)*1)/LISTE_LIMITE)
#define WIDTH (jeu->width)
#define HEIGHT (jeu->height)

#define NB_FRAMES 10

//Structure imposée:

enum {ROUGE, VERT, BLEU, JAUNE, NOIR, BLANC, NB_COLOR};
enum {CERCLE, CARRE, TRIANGLE, DIAMANT, ETOILE, HEXAGONE, NB_SHAPE};

typedef enum _Difficulty Difficulty;
/*
Permet une gestion simplifiée des différentes difficultés
*/
enum _Difficulty {TUTO=JAUNE, FACILE=NOIR, INTERMEDIAIRE=BLANC, EXPERT=NB_COLOR};

typedef struct _Token Token;
struct _Token
{
	int color;
	int form;
};

typedef struct _PlayedToken PlayedToken;
struct _PlayedToken
{
	Token jeton;
	PlayedToken* next;
	PlayedToken* nextColor;
	PlayedToken* prevColor;
	PlayedToken* nextForm;
	PlayedToken* prevForm;
};

typedef struct _TokenList TokenList;
struct _TokenList
{
	PlayedToken* head;
	PlayedToken* tail;
	PlayedToken* head_color[NB_COLOR];
	PlayedToken* head_shape[NB_SHAPE];
	int taille;
};

//Structure utile aux animations

enum {SCALE, SHINE_SCALE, NB_ANIM_IMG};

typedef struct _AnimToken AnimToken;
/*
Liste chainée simple permettant un apport d'informations pour effectuer certaines animations
Utile pour supprimer des jetons par exemple
*/
struct _AnimToken
{
	Token jeton;
	AnimToken *next;
	int disparition;
	int anim_id;
};

typedef struct _AnimList AnimList;
/*
Permet de gérer une liste d'AnimToken pour effectuer des ajouts rapides en tête et en fin et ne pas avoir à recalculer la taille
*/
struct _AnimList
{
	AnimToken *head;
	AnimToken *tail;
	int taille;
};

typedef struct _AnimData AnimData;
/*
Permet de placer en mémoire des images calculées ou chargées pour permettre un simple appel à l'affichage
Garde aussi en mémoire une AnimList pour permettre la gestion des animations à faire
*/
struct _AnimData
{
	AnimList *listeanim;
	MLV_Image *jetonimage[NB_COLOR][NB_SHAPE];
	MLV_Image *jetonimageanim[NB_COLOR][NB_SHAPE][NB_ANIM_IMG][NB_FRAMES];
	int loaded;
};

//Structure de gestion de l'interface

typedef enum _Control Control;
/*
Permet de connaître l'action choisie par le joueur (ajout en tete/fin)
*/
enum _Control{Control_None, Control_Tete, Control_Fin};

typedef enum _Choix_Rotate Choix_Rotate;
/*
Permet d'obtenir des informations sur la rotation chosie durant le jeu
*/
enum _Choix_Rotate{CR_None,CR_Couleur,CR_Forme};

typedef enum _Game_Mode Game_Mode;
/*
Permet de choisir plusieurs modes de jeu
*/
enum _Game_Mode{Game_Mode_Base, Game_Mode_Anim};

typedef struct _Tuto Tuto;
struct _Tuto
{
	char *message;
	int x, y;
	Control control_action;
	Choix_Rotate cr_action;
	Tuto *next;
};

typedef struct _Jeu Jeu;
/*
Structure de gestion du jeu dans laquelle on trouve:
-Des variables d'information sur le jeu (score, actif, need_refresh)
-Les listes chainées:
--listejeton liste du plateau
--genjeton jetons générés
-police pour l'affichage de texte
-nb_colors et nb_shapes pour régler la difficulté
-game_mode le mode de jeu
-Les fonctions permettant l'affichage selon le mode de jeu choisi
*/
struct _Jeu
{
	int win;
	int score;
	int actif;
	int need_refresh;
	int width;
	int height;
	int start_time;
	int party_time;
	TokenList *listejeton;
	TokenList *genjeton;
	AnimData *animdata;
	MLV_Font *police;
	MLV_Image *plateau;
	Avatar *avatar;
	
	char pseudo[123];
	
	int nb_colors;
	int nb_shapes;
	
	int is_tuto;
	int is_loaded;
	
	Game_Mode game_mode;
	void (*prepare_sprites)(int, int);
	void (*afficher)();
	void (*afficher_Liste)(TokenList *, int, int);
	void (*afficher_GenListe)(TokenList *, int, int);
	int (*genListe_Y)();
	void (*afficher_AnimList)(AnimList *, int, int);
	void (*afficher_control)();
	void (*afficher_plateau)(int);
	void (*afficher_jeton)(Token, int, int);
	Control (*get_control_action)(int, int);
	PlayedToken *(*get_PlayedToken)(TokenList *, int, int);
	int (*afficher_choix_rotate)(PlayedToken *, int, int);
	Choix_Rotate (*get_choix_rotate_action)(int, int, int, int);
	void (*afficher_rotate)(TokenList *, Choix_Rotate, int, int, int);
	void (*move_jeton)(Token, int, int, int, int);
	int (*startPosX)(int);
	int (*startPosY)(int);
	int (*spPosX)(int, int);
	int (*spPosY)(int, int);
	void (*afficher_ajout_score)(int, int, int);
	void (*afficher_avatar)(Avatar*);
};

Jeu *jeu;

#endif
